(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    142590,       2703]
NotebookOptionsPosition[    142231,       2689]
NotebookOutlinePosition[    142632,       2705]
CellTagsIndexPosition[    142589,       2702]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{"(*", 
   RowBox[{"common", " ", "settings"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "=", "320"}], ",", 
     RowBox[{"wButton", "=", "150"}], ",", 
     RowBox[{"wText", "=", "80"}], ",", 
     RowBox[{"defaultBlue", "=", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0.8", ",", "0.8", ",", "0.9"}], "]"}]}], ",", 
     RowBox[{"backgroundGray", "=", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0.96", ",", "0.96", ",", "0.94"}], "]"}]}], ",", 
     RowBox[{"buttonBlue", "=", 
      RowBox[{"RGBColor", "[", 
       RowBox[{".7", ",", ".775", ",", ".85"}], "]"}]}], ",", 
     RowBox[{"nLinesGrid", "=", "3"}], ",", 
     RowBox[{"mMax", "=", "20"}], ",", 
     RowBox[{"nMax", "=", "20"}], ",", 
     RowBox[{"textColor", "=", 
      RowBox[{"RGBColor", "[", 
       RowBox[{".15", ",", ".15", ",", ".4"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "selectedRegion", " ", "is", " ", "a", " ", "function", " ", "needed", 
        " ", "for", " ", "\"\<Merge Cells\>\"", " ", "and", " ", 
        "\"\<Unmerge Cells\>\"", " ", "where", " ", "the", " ", "selected", 
        " ", "cells", " ", "must", " ", "be", " ", "a", " ", "rectangular", 
        " ", 
        RowBox[{"shape", ".", " ", "It"}], " ", "takes", " ", "a", " ", 
        "Boolean", " ", "matrix", " ", 
        RowBox[{"(", "checkboxMatrix", ")"}], " ", "and", " ", "returns", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"iMin", ",", "iMax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"jMin", ",", "jMax"}], "}"}]}], "}"}], " ", "which", " ", 
        "is", " ", "the", " ", "bounds", " ", "of", " ", "the", " ", 
        "submatrix", " ", "containing", " ", "all", " ", "the", " ", "True", 
        " ", 
        RowBox[{"entries", ".", " ", "If"}], " ", "there", " ", "is", " ", 
        "not", " ", "a", " ", "rectangular", " ", "region", " ", "with", " ", 
        "all", " ", "the", " ", "True", " ", "values", " ", "and", " ", 
        "only", " ", "containing", " ", "True", " ", "values"}], ",", " ", 
       RowBox[{"it", " ", "returns", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "."}]}]}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"selectedRegion", "=", 
      RowBox[{"M", "\[Function]", "\[IndentingNewLine]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"m", "=", 
            RowBox[{"First", "[", 
             RowBox[{"Dimensions", "[", "M", "]"}], "]"}]}], ",", 
           RowBox[{"n", "=", 
            RowBox[{"Last", "[", 
             RowBox[{"Dimensions", "[", "M", "]"}], "]"}]}], ",", 
           RowBox[{"row", "=", 
            RowBox[{"i", "\[Function]", 
             RowBox[{"M", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
           RowBox[{"col", "=", 
            RowBox[{"j", "\[Function]", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "&"}], "/@", "M"}]}]}]}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"ijRange", "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Position", "[", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Or", "@@", 
                    RowBox[{"row", "[", "i", "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "1", ",", "m"}], "}"}]}], "]"}], ",", 
                    "True"}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}], "//", 
                 "Flatten"}], "//", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Min", "[", "#", "]"}], ",", 
                   RowBox[{"Max", "[", "#", "]"}]}], "}"}], "&"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Position", "[", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Or", "@@", 
                    RowBox[{"col", "[", "j", "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
                    "True"}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], "//", 
                 "Flatten"}], "//", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Min", "[", "#", "]"}], ",", 
                   RowBox[{"Max", "[", "#", "]"}]}], "}"}], "&"}]}]}], 
              "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"And", "@@", 
              RowBox[{"Flatten", "[", 
               RowBox[{"M", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ";;", 
                   RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1"}], "]"}], "]"}], ";;", 
                   RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], "]"}], "]"}], 
               "]"}]}], ",", "\[IndentingNewLine]", "ijRange", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}]}], 
          "\[IndentingNewLine]", "]"}]}], "]"}]}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"With", "[", 
    RowBox[{"(*", 
     RowBox[{
     "common", " ", "text", " ", "wrappers", " ", "and", " ", "common", " ", 
      "graphics", " ", "for", " ", "icons"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"textWrapper", "=", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "Bold", ",", "10", ",", "textColor"}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "5"}], ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "100"}], ",", "0"}], "}"}], ",", 
              RowBox[{"8", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"wText", ",", "Automatic"}], "}"}]}]}], "]"}], "&"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"textWrapper2", "=", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "10", ",", "textColor"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "50"}], ",", "0"}], "}"}], ",", 
              RowBox[{"8", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"50", ",", "Automatic"}], "}"}]}]}], "]"}], "&"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"textWrapperCentered", "=", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#1", ",", "Bold", ",", "10", ",", "textColor"}], "]"}], 
            "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"75", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
              RowBox[{"8", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"150", ",", "Automatic"}], "}"}]}]}], "]"}], "&"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"commonGridLines", "=", 
        RowBox[{
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Epsilon]", "=", "0.2"}], "}"}], ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"AbsoluteThickness", "[", "1", "]"}], ",", "#", ",", 
               RowBox[{"AbsolutePointSize", "[", "1.5", "]"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Point", "[", 
                  RowBox[{"{", 
                   RowBox[{"x", ",", "y"}], "}"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", 
                   RowBox[{"1", "/", "2"}], ",", 
                   RowBox[{"nLinesGrid", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"y", ",", 
                   RowBox[{"1", "/", "2"}], ",", 
                   RowBox[{"nLinesGrid", "+", 
                    RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "}"}], ",", 
             RowBox[{"PlotRange", "->", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "\[Epsilon]"}], ",", 
                  RowBox[{"nLinesGrid", "+", "\[Epsilon]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "\[Epsilon]"}], ",", 
                  RowBox[{"nLinesGrid", "+", "\[Epsilon]"}]}], "}"}]}], 
               "}"}]}], ",", 
             RowBox[{"ImageSize", "->", "18"}], ",", 
             RowBox[{"Background", "->", "White"}]}], "]"}]}], "]"}], "&"}]}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"commonCellLines", "=", 
        RowBox[{
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Epsilon]", "=", "0.1"}], "}"}], ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"AbsoluteThickness", "[", "0.75", "]"}], ",", "#"}], 
              "}"}], ",", 
             RowBox[{"PlotRange", "->", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "\[Epsilon]"}], ",", 
                  RowBox[{"1", "+", "\[Epsilon]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "\[Epsilon]"}], ",", 
                  RowBox[{"1", "+", "\[Epsilon]"}]}], "}"}]}], "}"}]}], ",", 
             RowBox[{"ImageSize", "->", "15"}], ",", 
             RowBox[{"Background", "->", "White"}]}], "]"}]}], "]"}], 
         "&"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"With", "[", 
      RowBox[{"(*", 
       RowBox[{"icon", " ", "graphics"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"outRightIcon", "=", 
          RowBox[{"commonGridLines", "[", 
           RowBox[{"{", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"nLinesGrid", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"nLinesGrid", ",", "nLinesGrid"}], "}"}]}], "}"}], 
             "]"}], "}"}], "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"outLeftIcon", "=", 
          RowBox[{"commonGridLines", "[", 
           RowBox[{"{", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "nLinesGrid"}], "}"}]}], "}"}], "]"}], 
            "}"}], "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"inVerIcon", "=", 
          RowBox[{"commonGridLines", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"#", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"#", ",", "nLinesGrid"}], "}"}]}], "}"}], "]"}], 
              "&"}], "/@", 
             RowBox[{"Range", "[", 
              RowBox[{"1", ",", 
               RowBox[{"nLinesGrid", "-", "1"}]}], "]"}]}], "}"}], "]"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"outBottomIcon", "=", 
          RowBox[{"commonGridLines", "[", 
           RowBox[{"{", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"nLinesGrid", ",", "0"}], "}"}]}], "}"}], "]"}], 
            "}"}], "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"outTopIcon", "=", 
          RowBox[{"commonGridLines", "[", 
           RowBox[{"{", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "nLinesGrid"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"nLinesGrid", ",", "nLinesGrid"}], "}"}]}], "}"}], 
             "]"}], "}"}], "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"inHorIcon", "=", 
          RowBox[{"commonGridLines", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "#"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"nLinesGrid", ",", "#"}], "}"}]}], "}"}], "]"}], 
              "&"}], "/@", 
             RowBox[{"Range", "[", 
              RowBox[{"1", ",", 
               RowBox[{"nLinesGrid", "-", "1"}]}], "]"}]}], "}"}], "]"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"leftCellLines", "=", 
          RowBox[{"commonCellLines", "[", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rightCellLines", "=", 
          RowBox[{"commonCellLines", "[", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}]}], "}"}], "]"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"aboveCellLines", "=", 
          RowBox[{"commonCellLines", "[", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}]}], "}"}], "]"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"belowCellLines", "=", 
          RowBox[{"commonCellLines", "[", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "0"}], "}"}]}], "}"}], "]"}], "]"}]}]}], 
        "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"NotebookSave", "[", 
        RowBox[{"CreatePalette", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"DynamicModule", "[", 
           RowBox[{"(*", 
            RowBox[{
            "Define", " ", "and", " ", "initialize", " ", "all", " ", 
             "dynamic", " ", "variables"}], "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"m", "=", "2"}], ",", 
              RowBox[{"n", "=", "3"}], ",", "selection", ",", "matrix", ",", 
              "cell", ",", 
              RowBox[{"spanFrom", "=", "\"\<None\>\""}], ",", 
              RowBox[{"cellFrame", "=", 
               RowBox[{"{", "}"}]}], ",", 
              RowBox[{"cellBackground", "=", "\"\<Inherited\>\""}], ",", 
              RowBox[{"tableBackground", "=", "None"}], ",", 
              RowBox[{"horAlignCell", "=", "Automatic"}], ",", 
              RowBox[{"verAlignCell", "=", "Automatic"}], ",", 
              RowBox[{"horAlignTable", "=", "Automatic"}], ",", 
              RowBox[{"verAlignTable", "=", "Automatic"}], ",", 
              RowBox[{"xCellSize", "=", "Automatic"}], ",", 
              RowBox[{"yCellSize", "=", "Automatic"}], ",", 
              RowBox[{"xCellSizeTable", "=", "Automatic"}], ",", 
              RowBox[{"yCellSizeTable", "=", "Automatic"}], ",", 
              RowBox[{"frame", "=", 
               RowBox[{"{", "}"}]}], ",", 
              RowBox[{"cellFrameInheritedQ", "=", "True"}], ",", 
              RowBox[{"otherCellBackground", "=", "defaultBlue"}], ",", 
              RowBox[{"otherTableBackground", "=", "defaultBlue"}], ",", 
              "tableBackgroundSelection", ",", "cellBackgroundSelection", ",", 
              RowBox[{"otherFrameQ", "=", "False"}], ",", 
              RowBox[{"vLines", "=", 
               RowBox[{"{", "}"}]}], ",", 
              RowBox[{"hLines", "=", 
               RowBox[{"{", "}"}]}], ",", 
              RowBox[{"dims", "=", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}]}], ",", "checkboxMatrix", ",", 
              
              RowBox[{"tableSetFrameQ", "=", "False"}], ",", 
              RowBox[{"tableSetFrameAllQ", "=", "False"}], ",", 
              RowBox[{"rTable", "=", "255"}], ",", 
              RowBox[{"gTable", "=", "255"}], ",", 
              RowBox[{"bTable", "=", "255"}], ",", 
              RowBox[{"rCell", "=", "255"}], ",", 
              RowBox[{"gCell", "=", "255"}], ",", 
              RowBox[{"bCell", "=", "255"}], ",", 
              RowBox[{"mergeError", "=", "\"\<\>\""}], ",", "ijRange"}], 
             "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"With", "[", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{"(*", 
                RowBox[{"This", " ", "builds", " ", 
                 RowBox[{"tableOptions", ".", " ", "This"}], " ", "is", " ", 
                 "added", " ", "to", " ", "Grid", " ", "to", " ", "be", " ", 
                 "pasted", " ", "by", " ", "the", " ", "\"\<Make Table\>\"", 
                 " ", 
                 RowBox[{"button", "."}]}], "*)"}], "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"tableOptions", "=", 
                 RowBox[{
                  RowBox[{"Join", "[", "\[IndentingNewLine]", 
                   RowBox[{"(*", 
                    RowBox[{"BackGround", " ", "for", " ", "Table"}], "*)"}], 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Background", "->", "tableBackground"}], "}"}], 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Cell", " ", "Size", " ", "for", " ", "Table"}], 
                    "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"ItemSize", "->", 
                    RowBox[{"{", 
                    RowBox[{"xCellSizeTable", ",", "yCellSizeTable"}], 
                    "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"Alignment", "->", 
                    RowBox[{"{", 
                    RowBox[{"horAlignTable", ",", "verAlignTable"}], "}"}]}], 
                    "}"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"(*", 
                    RowBox[{
                    "Dividers", " ", "and", " ", "Frame", " ", "for", " ", 
                    "Table"}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"Which", "[", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"When", " ", "\"\<Other\>\"", " ", "is", " ", 
                    RowBox[{"checked", "."}]}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"otherFrameQ", ",", "\[IndentingNewLine]", 
                    RowBox[{"Dividers", "->", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"hLines", ",", "j"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"Range", "[", 
                    RowBox[{"1", ",", 
                    RowBox[{"n", "+", "1"}]}], "]"}]}], "}"}]}], "]"}], ",", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"vLines", ",", "i"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Range", "[", 
                    RowBox[{"1", ",", 
                    RowBox[{"m", "+", "1"}]}], "]"}]}], "}"}]}], "]"}]}], 
                    "}"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    "When", " ", "\"\<tableSetFrameAllQ\>\"", " ", "is", " ", 
                    
                    RowBox[{"checked", "."}]}], "*)"}], "\[IndentingNewLine]",
                     "tableSetFrameAllQ", ",", "\[IndentingNewLine]", 
                    RowBox[{"Frame", "->", "All"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    "When", " ", "\"\<tableSetFrameQ\>\"", " ", "is", " ", 
                    RowBox[{"checked", "."}]}], "*)"}], "\[IndentingNewLine]",
                     "tableSetFrameQ", ",", "\[IndentingNewLine]", 
                    RowBox[{"Frame", "->", "True"}], ",", 
                    RowBox[{"(*", 
                    RowBox[{
                    "Different", " ", "arrangements", " ", "of", " ", 
                    "\"\<Lines\>\""}], "*)"}], "\[IndentingNewLine]", "True", 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"With", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"ver", "=", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"frame", ",", "#"}], "]"}], "&"}], ")"}], "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<Outside Left\>\"", ",", "\"\<Inside Vertical\>\"", 
                    ",", "\"\<Outside Right\>\""}], "}"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"hor", "=", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"frame", ",", "#"}], "]"}], "&"}], ")"}], "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<Outside Top\>\"", ",", "\"\<Inside Horizontal\>\"", 
                    ",", "\"\<Outside Bottom\>\""}], "}"}]}]}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Switch", "[", 
                    RowBox[{
                    RowBox[{"Join", "[", 
                    RowBox[{"ver", ",", "hor"}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Simple", " ", "cases", " ", "use", " ", 
                    RowBox[{"Frame", "."}]}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True"}], "}"}], ",", 
                    RowBox[{"Frame", "->", "All"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    "True", ",", "False", ",", "True", ",", "True", ",", 
                    "False", ",", "True"}], "}"}], ",", 
                    RowBox[{"Frame", "->", "True"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    "False", ",", "False", ",", "False", ",", "False", ",", 
                    "False", ",", "False"}], "}"}], ",", 
                    RowBox[{"Frame", "->", "None"}], ",", 
                    "\[IndentingNewLine]", "_", ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Other", " ", "combinations", " ", "use", " ", 
                    RowBox[{"Dividers", "."}]}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{"dividerFn", "=", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"horver", ",", "nm"}], "}"}], "\[Function]", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Switch", "[", 
                    RowBox[{"horver", ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "True", ",", "False"}], "}"}], ",", 
                    "Center", ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "False"}], "}"}], ",",
                     "False", ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "False", ",", "False"}], "}"}], ",", 
                    
                    RowBox[{"{", 
                    RowBox[{"1", "->", "True"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "True"}], "}"}], ",", 
                    
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], "->", "True"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "False", ",", "True"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "->", "True"}], ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "->", "True"}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True", ",", "False"}], "}"}], ",", 
                    RowBox[{"Join", "[", 
                    RowBox[{
                    RowBox[{"ConstantArray", "[", 
                    RowBox[{"True", ",", "nm"}], "]"}], ",", 
                    RowBox[{"{", "False", "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "True", ",", "True"}], "}"}], ",", 
                    RowBox[{"Join", "[", 
                    RowBox[{
                    RowBox[{"{", "False", "}"}], ",", 
                    RowBox[{"ConstantArray", "[", 
                    RowBox[{"True", ",", "nm"}], "]"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True", ",", "True"}], "}"}], ",", 
                    "All", ",", "\[IndentingNewLine]", "_", ",", "None"}], 
                    "]"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Dividers", "->", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"dividerFn", "[", 
                    RowBox[{"ver", ",", "n"}], "]"}], ",", 
                    RowBox[{"dividerFn", "[", 
                    RowBox[{"hor", ",", "m"}], "]"}]}], "}"}]}]}], 
                    "\[IndentingNewLine]", "]"}]}], "]"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "]"}], "}"}]}], 
                   "\[IndentingNewLine]", "]"}], "//", "Dynamic"}]}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"(*", 
                 RowBox[{
                 "This", " ", "builds", " ", "cellOptions", " ", "that", " ", 
                  "is", " ", "added", " ", "to", " ", "the", " ", "ItemBox", 
                  " ", "for", " ", "the", " ", "cell", " ", "to", " ", "be", 
                  " ", "modified", " ", "by", " ", 
                  RowBox[{"\"\<Update Cells\>\"", "."}]}], "*)"}], 
                "\[IndentingNewLine]", 
                RowBox[{"cellOptions", "=", 
                 RowBox[{
                  RowBox[{"Join", "[", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{"cellFrameInheritedQ", ",", 
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Frame", "->", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"cellFrame", ",", "\"\<Left\>\""}], "]"}], ",", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"cellFrame", ",", "\"\<Right\>\""}], "]"}]}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"cellFrame", ",", "\"\<Below\>\""}], "]"}], ",", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"cellFrame", ",", "\"\<Above\>\""}], "]"}]}], 
                    "}"}]}], "}"}]}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"cellBackground", "===", "\"\<Inherited\>\""}], 
                    ",", 
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Background", "->", "cellBackground"}], "}"}]}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"AC", "=", 
                    RowBox[{"{", 
                    RowBox[{"horAlignCell", ",", "verAlignCell"}], "}"}]}], 
                    "}"}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"AC", "===", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], ",", 
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Alignment", "->", "AC"}], "}"}]}], "]"}]}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"IS", "=", 
                    RowBox[{"{", 
                    RowBox[{"xCellSize", ",", "yCellSize"}], "}"}]}], "}"}], 
                    ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"IS", "===", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], ",", 
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"ItemSize", "->", "IS"}], "}"}]}], "]"}]}], 
                    "]"}]}], "]"}], "//", "Dynamic"}]}]}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{
               "The", " ", "body", " ", "of", " ", "the", " ", "palette"}], 
               "*)"}], "\[IndentingNewLine]", 
              RowBox[{"Column", "[", 
               RowBox[{
                RowBox[{"{", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Column", "[", 
                   RowBox[{
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Make", " ", "Table", " ", "button"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Row", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Button", "[", 
                    RowBox[{
                    RowBox[{"\"\<Make Table\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "12"}], "]"}], "&"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Paste", "[", 
                    RowBox[{"Grid", "[", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{"\[Placeholder]", ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "1", ",", "m"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
                    RowBox[{"Sequence", "@@", "tableOptions"}]}], "]"}], 
                    "]"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "wButton"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}], ",", 
                    RowBox[{"Background", "\[Rule]", "buttonBlue"}]}], "]"}], 
                    "//", "Dynamic"}], ",", "\[IndentingNewLine]", 
                    "\"\<Select table dimensions to the right and options \
below before clicking.\>\""}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"m", "//", "Dynamic"}], ",", 
                    RowBox[{"Range", "[", "mMax", "]"}], ",", 
                    RowBox[{"MenuStyle", "\[Rule]", "11"}]}], "]"}], ",", 
                    RowBox[{"\"\<\[Times]\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "14"}], "]"}], "&"}]}], ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"n", "//", "Dynamic"}], ",", 
                    RowBox[{"Range", "[", "nMax", "]"}], ",", 
                    RowBox[{"MenuStyle", "\[Rule]", "11"}]}], "]"}]}], "}"}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Spacer", "[", "10", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Button", "[", 
                    RowBox[{
                    RowBox[{"\"\<Reset\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "12"}], "]"}], "&"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    "cellBackgroundSelection", "=", "\"\<Inhereted\>\""}], 
                    ";", 
                    RowBox[{"m", "=", "2"}], ";", 
                    RowBox[{"n", "=", "3"}], ";", 
                    RowBox[{"cellBackground", "=", "\"\<Inherited\>\""}], ";", 
                    RowBox[{"spanFrom", "=", "\"\<None\>\""}], ";", 
                    RowBox[{"tableBackground", "=", 
                    RowBox[{"tableBackgroundSelection", "=", "None"}]}], ";", 
                    
                    RowBox[{"horAlignCell", "=", 
                    RowBox[{"verAlignCell", "=", 
                    RowBox[{"horAlignTable", "=", 
                    RowBox[{"verAlignTable", "=", 
                    RowBox[{"xCellSize", "=", 
                    RowBox[{"yCellSize", "=", 
                    RowBox[{"xCellSizeTable", "=", 
                    RowBox[{
                    "yCellSizeTable", "=", "Automatic"}]}]}]}]}]}]}]}], ";", 
                    RowBox[{"cellFrameInheritedQ", "=", "True"}], ";", 
                    RowBox[{"otherCellBackground", "=", "defaultBlue"}], ";", 
                    
                    RowBox[{"otherTableBackground", "=", "defaultBlue"}], ";", 
                    RowBox[{"otherFrameQ", "=", "False"}], ";", 
                    RowBox[{"frame", "=", 
                    RowBox[{"cellFrame", "=", 
                    RowBox[{"vLines", "=", 
                    RowBox[{"hLines", "=", 
                    RowBox[{"{", "}"}]}]}]}]}], ";", 
                    RowBox[{"dims", "=", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], ";", 
                    RowBox[{"tableSetFrameQ", "=", 
                    RowBox[{"tableSetFrameAllQ", "=", "False"}]}], ";", 
                    RowBox[{"rTable", "=", 
                    RowBox[{"gTable", "=", 
                    RowBox[{"bTable", "=", 
                    RowBox[{"rCell", "=", 
                    RowBox[{"gCell", "=", 
                    RowBox[{"bCell", "=", "255"}]}]}]}]}]}], ";", 
                    RowBox[{"mergeError", "=", "\"\<\>\""}]}], ")"}], "//", 
                    "Dynamic"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"wButton", "/", "3"}]}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}], ",", 
                    RowBox[{"Background", "\[Rule]", "buttonBlue"}]}], "]"}], 
                    ",", "\[IndentingNewLine]", 
                    "\"\<Fully reset the palette\>\""}], "]"}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Alignment", "\[Rule]", "Right"}], ",", 
                    RowBox[{"ImageSize", "->", 
                    RowBox[{"w", "-", "wButton"}]}]}], "]"}]}], 
                    "\[IndentingNewLine]", "}"}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Lines", " ", "for", " ", "Table"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    "textWrapper", "[", "\"\<Frame/Dividers:\>\"", "]"}], ",",
                     "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{"otherFrameQ", ",", "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"textWrapper2", "[", "\"\<Horizontal\>\"", "]"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"TogglerBar", "[", 
                    RowBox[{
                    RowBox[{"vLines", "//", "Dynamic"}], ",", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"i", "+", "1"}], "->", "i"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", "m"}], "]"}]}], "}"}]}], "]"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}], "//", "Dynamic"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"textWrapper2", "[", "\"\<Vertical\>\"", "]"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"TogglerBar", "[", 
                    RowBox[{
                    RowBox[{"hLines", "//", "Dynamic"}], ",", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"j", "+", "1"}], "->", "j"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", "n"}], "]"}]}], "}"}]}], "]"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}], "//", "Dynamic"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "}"}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Checkbox", "[", 
                    RowBox[{"tableSetFrameAllQ", "//", "Dynamic"}], "]"}], 
                    ",", "\"\<All\>\""}], "}"}], ",", 
                    RowBox[{"Alignment", "->", "Center"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Checkbox", "[", 
                    RowBox[{"tableSetFrameQ", "//", "Dynamic"}], "]"}], ",", 
                    "\"\<Frame\>\""}], "}"}], ",", 
                    RowBox[{"Alignment", "->", "Center"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"TogglerBar", "[", 
                    RowBox[{
                    RowBox[{"frame", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\"\<Outside Left\>\"", "->", "outLeftIcon"}], 
                    ",", 
                    RowBox[{"\"\<Inside Vertical\>\"", "->", "inVerIcon"}], 
                    ",", 
                    RowBox[{"\"\<Outside Right\>\"", "->", "outRightIcon"}], 
                    ",", 
                    RowBox[{"\"\<Outside Top\>\"", "->", "outTopIcon"}], ",", 
                    
                    RowBox[{"\"\<Inside Horizontal\>\"", "->", "inHorIcon"}], 
                    ",", 
                    RowBox[{
                    "\"\<Outside Bottom\>\"", "->", "outBottomIcon"}]}], 
                    "}"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}]}], "}"}], "]"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Checkbox", "[", 
                    RowBox[{"otherFrameQ", "//", "Dynamic"}], "]"}], ",", 
                    "\"\<Other\>\""}], "}"}], ",", 
                    RowBox[{"Alignment", "->", "Center"}]}], "]"}], "}"}], 
                    "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "w"}]}], "]"}], 
                    "\[IndentingNewLine]", "}"}], "]"}], "//", "Dynamic"}], 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Table", " ", "Background"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{"Join", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"textWrapper", "[", "\"\<Background:\>\"", "]"}], 
                    ",", 
                    RowBox[{"SetterBar", "[", 
                    RowBox[{
                    RowBox[{"tableBackgroundSelection", "//", "Dynamic"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"None", ",", 
                    RowBox[{"White", "->", "\"\<White\>\""}], ",", 
                    RowBox[{"defaultBlue", "->", "\"\<Light Blue\>\""}], ",", 
                    "\"\<Other\>\""}], "}"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
                    RowBox[{"ImageSize", "->", "w"}]}], "]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    "tableBackgroundSelection", "=!=", "\"\<Other\>\""}], ",",
                     "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    "tableBackground", "=", "tableBackgroundSelection"}], ";", 
                    RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"tableBackground", "=", 
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    FractionBox["rTable", "255"], ",", 
                    FractionBox["gTable", "255"], ",", 
                    FractionBox["bTable", "255"]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    RowBox[{"Graphics", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    FractionBox["rTable", "255"], ",", 
                    FractionBox["gTable", "255"], ",", 
                    FractionBox["bTable", "255"]}], "]"}], "//", "Dynamic"}], 
                    ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"{", 
                    RowBox[{"Black", ",", 
                    RowBox[{"AbsoluteThickness", "[", "1", "]"}]}], "}"}], 
                    "]"}], ",", 
                    RowBox[{"Rectangle", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "1"}], "}"}]}], "]"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "->", "60"}]}], "]"}], ",", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"rTable", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "255", ",", "1"}], "}"}]}], "]"}], ",", 
                    
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    RowBox[{"rTable", "//", "Dynamic"}], ",", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", "\"\<Red\>\""}], 
                    "}"}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"gTable", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "255", ",", "1"}], "}"}]}], "]"}], ",", 
                    
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    RowBox[{"gTable", "//", "Dynamic"}], ",", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", "\"\<Green\>\""}],
                     "}"}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"bTable", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "255", ",", "1"}], "}"}]}], "]"}], ",", 
                    
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    RowBox[{"bTable", "//", "Dynamic"}], ",", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", "\"\<Blue\>\""}], 
                    "}"}], "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
                    "}"}], "]"}]}], ")"}], "}"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "]"}], "]"}], "//", "Dynamic"}], 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    RowBox[{"Cell", " ", "Size"}], " ", "-", " ", "Table"}], 
                    "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"textWrapper", "[", "\"\<Cell Size:\>\"", "]"}], 
                    ",", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\"\<{\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "16"}], "]"}], "&"}]}], ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"xCellSizeTable", "//", "Dynamic"}], ",", 
                    RowBox[{"Prepend", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", "50", "]"}], ",", "Automatic"}], 
                    "]"}], ",", 
                    RowBox[{"MenuStyle", "\[Rule]", "11"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\"\<,\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "16"}], "]"}], "&"}]}], ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"yCellSizeTable", "//", "Dynamic"}], ",", 
                    RowBox[{"Prepend", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", "50", "]"}], ",", "Automatic"}], 
                    "]"}], ",", 
                    RowBox[{"MenuStyle", "\[Rule]", "11"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\"\<}\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "16"}], "]"}], "&"}]}]}], "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
                    RowBox[{"ImageSize", "->", 
                    RowBox[{"w", "-", "wText", "-", "10"}]}]}], "]"}]}], 
                    "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
                    RowBox[{"ImageSize", "->", "w"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Center"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Alignment", " ", "-", " ", "Table"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    "textWrapperCentered", "[", 
                    "\"\<Horizontal Alignment\>\"", "]"}], ",", 
                    RowBox[{"SetterBar", "[", 
                    RowBox[{
                    RowBox[{"horAlignTable", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Automatic", "->", "\"\<None\>\""}], ",", "Left", 
                    ",", "Center", ",", "Right"}], "}"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "->", "Center"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Spacer", "[", "5", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    "textWrapperCentered", "[", "\"\<Vertical Alignment\>\"", 
                    "]"}], ",", 
                    RowBox[{"SetterBar", "[", 
                    RowBox[{
                    RowBox[{"verAlignTable", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Automatic", "->", "\"\<None\>\""}], ",", 
                    "Bottom", ",", "Center", ",", "Top"}], "}"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "->", "Center"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Center"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Center"}], ",", 
                    RowBox[{"Dividers", "\[Rule]", "Center"}], ",", 
                    RowBox[{"FrameStyle", "->", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", ".5", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", ".75", "]"}]}], "}"}]}]}], 
                   "]"}], ",", "\[IndentingNewLine]", 
                  RowBox[{"(*", 
                   RowBox[{"Update", " ", "Cells"}], "*)"}], 
                  "\[IndentingNewLine]", 
                  RowBox[{"Column", "[", 
                   RowBox[{
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Row", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    "\"\<Select Table\>\"", " ", "button", " ", "will", " ", 
                    "select", " ", "some", " ", "table", " ", "in", " ", "a", 
                    " ", 
                    RowBox[{"nb", "."}]}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Button", "[", 
                    RowBox[{
                    RowBox[{"\"\<Select Table\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "12"}], "]"}], "&"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    "This", " ", "expands", " ", "the", " ", "selection", " ",
                     "in", " ", "the", " ", "current", " ", "notebook", " ", 
                    "to", " ", "contain", " ", "the", " ", "entire", " ", 
                    RowBox[{"GridBox", ".", " ", "The"}], " ", "While", " ", 
                    "loop", " ", "repeatedly", " ", "expands", " ", "the", 
                    " ", "current", " ", "selection", " ", "until", " ", "it",
                     " ", "stops", " ", "at", " ", "a", " ", 
                    RowBox[{"GridBox", ".", " ", "If"}], " ", "the", " ", 
                    "selection", " ", "is", " ", "not", " ", "inside", " ", 
                    "a", " ", "GridBox", " ", "the", " ", "loop", " ", "will",
                     " ", "fail", " ", 
                    RowBox[{"quickly", "."}]}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"While", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"selection", "=", 
                    RowBox[{"NotebookRead", "[", 
                    RowBox[{"InputNotebook", "[", "]"}], "]"}]}], ";", 
                    RowBox[{
                    RowBox[{"Head", "[", "selection", "]"}], "=!=", 
                    "GridBox"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"SelectionMove", "[", 
                    RowBox[{
                    RowBox[{"InputNotebook", "[", "]"}], ",", "All", ",", 
                    "Expression"}], "]"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"matrix", "=", 
                    RowBox[{"selection", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
                    RowBox[{"(*", 
                    RowBox[{
                    "matrix", " ", "is", " ", "the", " ", "matrix", " ", "of",
                     " ", "cells", " ", "inside", " ", "GridBox"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"dims", "=", 
                    RowBox[{"Dimensions", "[", "matrix", "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"checkboxMatrix", "=", 
                    RowBox[{"ConstantArray", "[", 
                    RowBox[{"False", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"dims", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"dims", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}]}]}], " ", 
                    RowBox[{"(*", 
                    RowBox[{
                    "checkboxMatrix", " ", "is", " ", "used", " ", "in", " ", 
                    "a", " ", "grid", " ", "of", " ", "Checkboxes", " ", "so",
                     " ", "select", " ", "cells", " ", "to", " ", 
                    RowBox[{"edit", "."}]}], "*)"}], ",", " ", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ImageSize", "\[Rule]", "wButton"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}], ",", 
                    RowBox[{"Background", "\[Rule]", "buttonBlue"}]}], "]"}], 
                    "//", "Dynamic"}], ",", "\[IndentingNewLine]", 
                    "\"\<Click with cursor anywhere in a table. This will \
create a Checkbox matrix of the cells.\>\""}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Row", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Button", "[", 
                    RowBox[{
                    RowBox[{"\"\<Merge Cells\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "12"}], "]"}], "&"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"While", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"selection", "=", 
                    RowBox[{"NotebookRead", "[", 
                    RowBox[{"InputNotebook", "[", "]"}], "]"}]}], ";", 
                    RowBox[{
                    RowBox[{"Head", "[", "selection", "]"}], "=!=", 
                    "GridBox"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"SelectionMove", "[", 
                    RowBox[{
                    RowBox[{"InputNotebook", "[", "]"}], ",", "All", ",", 
                    "Expression"}], "]"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ijRange", "=", 
                    RowBox[{"selectedRegion", "[", "checkboxMatrix", "]"}]}], 
                    ";", 
                    RowBox[{"(*", 
                    RowBox[{
                    "selectedRegion", " ", "is", " ", "a", " ", "function", 
                    " ", "defined", " ", 
                    RowBox[{"(", 
                    RowBox[{"and", " ", "described"}], ")"}], " ", "in", " ", 
                    "the", " ", "first", " ", "With", " ", 
                    RowBox[{"statement", "."}]}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ijRange", "===", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    "mergeError", "=", 
                    "\"\<Selection is not Rectangular\>\""}], ",", 
                    RowBox[{
                    RowBox[{"mergeError", "=", "\"\<\>\""}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"iMin", "=", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
                    RowBox[{"iMax", "=", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
                    RowBox[{"jMin", "=", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
                    RowBox[{"jMax", "=", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"temp", "=", 
                    RowBox[{"matrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"iMin", ",", "jMin"}], "]"}], "]"}]}], "}"}], ",",
                     "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Do", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"matrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
                    RowBox[{"Which", "[", 
                    RowBox[{
                    RowBox[{"i", "==", "iMin"}], ",", 
                    "\"\<\[SpanFromLeft]\>\"", ",", 
                    RowBox[{"j", "==", "jMin"}], ",", 
                    "\"\<\[SpanFromAbove]\>\"", ",", "True", ",", 
                    "\"\<\[SpanFromBoth]\>\""}], "]"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "iMin", ",", "iMax"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "jMin", ",", "jMax"}], "}"}]}], "]"}], 
                    ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"matrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"iMin", ",", "jMin"}], "]"}], "]"}], "=", 
                    "temp"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"NotebookDelete", "[", "selection", "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"NotebookWrite", "[", 
                    RowBox[{
                    RowBox[{"InputNotebook", "[", "]"}], ",", 
                    RowBox[{"selection", "/.", 
                    RowBox[{
                    RowBox[{"GridBox", "[", 
                    RowBox[{"x_", ",", "y__"}], "]"}], ":>", 
                    RowBox[{"GridBox", "[", 
                    RowBox[{"matrix", ",", "y"}], "]"}]}]}]}], "]"}]}]}], 
                    "]"}]}], "]"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"wButton", "/", "2"}]}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}], ",", 
                    RowBox[{"Background", "\[Rule]", "buttonBlue"}]}], "]"}], 
                    "//", "Dynamic"}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Button", "[", 
                    RowBox[{
                    RowBox[{"\"\<Unmerge\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "12"}], "]"}], "&"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"While", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"selection", "=", 
                    RowBox[{"NotebookRead", "[", 
                    RowBox[{"InputNotebook", "[", "]"}], "]"}]}], ";", 
                    RowBox[{
                    RowBox[{"Head", "[", "selection", "]"}], "=!=", 
                    "GridBox"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"SelectionMove", "[", 
                    RowBox[{
                    RowBox[{"InputNotebook", "[", "]"}], ",", "All", ",", 
                    "Expression"}], "]"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ijRange", "=", 
                    RowBox[{"selectedRegion", "[", "checkboxMatrix", "]"}]}], 
                    ";", "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ijRange", "===", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    "mergeError", "=", 
                    "\"\<Selection is not Rectangular\>\""}], ",", 
                    RowBox[{
                    RowBox[{"mergeError", "=", "\"\<\>\""}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"iMin", "=", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
                    RowBox[{"iMax", "=", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
                    RowBox[{"jMin", "=", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", 
                    RowBox[{"jMax", "=", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"temp", "=", 
                    RowBox[{"matrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"iMin", ",", "jMin"}], "]"}], "]"}]}], "}"}], ",",
                     "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Do", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"matrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
                    "\"\<\[Placeholder]\>\""}], ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"ijRange", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "}"}]}], "]"}], 
                    ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"matrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"iMin", ",", "jMin"}], "]"}], "]"}], "=", 
                    "temp"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"NotebookDelete", "[", "selection", "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"NotebookWrite", "[", 
                    RowBox[{
                    RowBox[{"InputNotebook", "[", "]"}], ",", 
                    RowBox[{"selection", "/.", 
                    RowBox[{
                    RowBox[{"GridBox", "[", 
                    RowBox[{"x_", ",", "y__"}], "]"}], ":>", 
                    RowBox[{"GridBox", "[", 
                    RowBox[{"matrix", ",", "y"}], "]"}]}]}]}], "]"}]}]}], 
                    "]"}]}], "]"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"wButton", "/", "2"}]}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}], ",", 
                    RowBox[{"Background", "\[Rule]", "buttonBlue"}]}], "]"}], 
                    "//", "Dynamic"}]}], "}"}], "]"}], ",", 
                    "\"\<To merge or unmerge cells, select a rectangular \
region in the Checkbox matrix to the right.\>\""}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    "\"\<Update Cells\>\"", " ", "button", " ", "applies", 
                    " ", "the", " ", "chosen", " ", "options", " ", "to", " ",
                     "selected", " ", 
                    RowBox[{"cells", "."}]}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Button", "[", 
                    RowBox[{
                    RowBox[{"\"\<Update Cells\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "12"}], "]"}], "&"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"While", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"selection", "=", 
                    RowBox[{"NotebookRead", "[", 
                    RowBox[{"InputNotebook", "[", "]"}], "]"}]}], ";", 
                    RowBox[{
                    RowBox[{"Head", "[", "selection", "]"}], "=!=", 
                    "GridBox"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"SelectionMove", "[", 
                    RowBox[{
                    RowBox[{"InputNotebook", "[", "]"}], ",", "All", ",", 
                    "Expression"}], "]"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Do", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"checkboxMatrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"cell", "=", 
                    RowBox[{"matrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ";", 
                    RowBox[{"(*", 
                    RowBox[{
                    "Select", " ", "the", " ", "particular", " ", "cell"}], 
                    "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"cell", "=", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Head", "[", "cell", "]"}], "===", "ItemBox"}], 
                    ",", 
                    RowBox[{"cell", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "cell"}], "]"}]}], 
                    ";", 
                    RowBox[{"(*", 
                    RowBox[{
                    "Strip", " ", "any", " ", "settings", " ", "from", " ", 
                    "the", " ", 
                    RowBox[{"cell", "."}]}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    "This", " ", "changes", " ", "the", " ", "value", " ", 
                    "of", " ", "the", " ", "cell", " ", "by", " ", "adding", 
                    " ", "the", " ", "options", " ", "using", " ", "an", " ", 
                    
                    RowBox[{"ItemBox", "."}]}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"matrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
                    RowBox[{"ItemBox", "[", 
                    RowBox[{"cell", ",", 
                    RowBox[{"Sequence", "@@", "cellOptions"}]}], "]"}]}]}]}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "1", ",", 
                    RowBox[{"dims", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "1", ",", 
                    RowBox[{"dims", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"NotebookDelete", "[", "selection", "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"NotebookWrite", "[", 
                    RowBox[{
                    RowBox[{"InputNotebook", "[", "]"}], ",", 
                    RowBox[{"selection", "/.", 
                    RowBox[{
                    RowBox[{"GridBox", "[", 
                    RowBox[{"x_", ",", "y__"}], "]"}], ":>", 
                    RowBox[{"GridBox", "[", 
                    RowBox[{"matrix", ",", "y"}], "]"}]}]}]}], "]"}]}], ",", 
                    RowBox[{"(*", 
                    RowBox[{
                    "Replace", " ", "the", " ", "matrix", " ", "in", " ", 
                    "GridBox"}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"ImageSize", "\[Rule]", "wButton"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}], ",", 
                    RowBox[{"Background", "\[Rule]", "buttonBlue"}]}], "]"}], 
                    "//", "Dynamic"}], ",", 
                    "\"\<Select cells in the Checkbox matrix to the right and \
choose options below before clicking.\>\""}], "]"}]}], "}"}], ",", 
                    RowBox[{"Spacings", "\[Rule]", "0"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"Join", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"dims", "===", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\"\<No table selected.\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "Bold", ",", "textColor"}], "]"}], 
                    "&"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Grid", "[", 
                    RowBox[{
                    RowBox[{"Outer", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Checkbox", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"checkboxMatrix", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", ",", "#2"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "True"}], "}"}]}], "]"}], "&"}], 
                    ",", 
                    RowBox[{"Range", "[", 
                    RowBox[{"dims", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
                    RowBox[{"Range", "[", 
                    RowBox[{"dims", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"Spacings", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}], "]"}], "}"}],
                     ",", 
                    RowBox[{"Alignment", "\[Rule]", "Center"}], ",", 
                    RowBox[{"ImageSize", "->", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"dims", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<", "10"}], ",", 
                    RowBox[{"w", "-", "wButton"}], ",", "Automatic"}], 
                    "]"}]}]}], "]"}], "}"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"mergeError", "===", "\"\<\>\""}], ",", 
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"{", "mergeError", "}"}]}], "]"}]}], "]"}], ",", 
                    RowBox[{"Alignment", "->", "Center"}]}], "]"}], "//", 
                    "Dynamic"}]}], "\[IndentingNewLine]", "}"}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Cell", " ", "Frame"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"textWrapper", "[", 
                    RowBox[{"\"\<Frame:\>\"", ",", "80"}], "]"}], ",", 
                    "\"\<Inherit cell frame \>\"", ",", 
                    RowBox[{"Checkbox", "[", 
                    RowBox[{"cellFrameInheritedQ", "//", "Dynamic"}], "]"}], 
                    ",", 
                    RowBox[{"Spacer", "[", "10", "]"}], ",", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{"cellFrameInheritedQ", ",", "\"\<\>\"", ",", 
                    RowBox[{"TogglerBar", "[", 
                    RowBox[{
                    RowBox[{"cellFrame", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\"\<Left\>\"", "->", "leftCellLines"}], ",", 
                    RowBox[{"\"\<Right\>\"", "->", "rightCellLines"}], ",", 
                    RowBox[{"\"\<Above\>\"", "->", "aboveCellLines"}], ",", 
                    RowBox[{"\"\<Below\>\"", "->", "belowCellLines"}]}], 
                    "}"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}]}], "]"}], "//", "Dynamic"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
                    RowBox[{"ImageSize", "->", "w"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Cell", " ", "Background"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{"Join", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"textWrapper", "[", "\"\<Background:\>\"", "]"}], 
                    ",", 
                    RowBox[{"SetterBar", "[", 
                    RowBox[{
                    RowBox[{"cellBackgroundSelection", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Inherited\>\"", ",", "None", ",", 
                    RowBox[{"White", "->", "\"\<White\>\""}], ",", 
                    RowBox[{"defaultBlue", "->", "\"\<Light Blue\>\""}], ",", 
                    "\"\<Other\>\""}], "}"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
                    RowBox[{"ImageSize", "->", "w"}]}], "]"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    "cellBackgroundSelection", "=!=", "\"\<Other\>\""}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    "cellBackground", "=", "cellBackgroundSelection"}], ";", 
                    RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"cellBackground", "=", 
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    FractionBox["rCell", "255"], ",", 
                    FractionBox["gCell", "255"], ",", 
                    FractionBox["bCell", "255"]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    RowBox[{"Graphics", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    FractionBox["rCell", "255"], ",", 
                    FractionBox["gCell", "255"], ",", 
                    FractionBox["bCell", "255"]}], "]"}], "//", "Dynamic"}], 
                    ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"{", 
                    RowBox[{"Black", ",", 
                    RowBox[{"AbsoluteThickness", "[", "1", "]"}]}], "}"}], 
                    "]"}], ",", 
                    RowBox[{"Rectangle", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "1"}], "}"}]}], "]"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "->", "60"}]}], "]"}], ",", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"rCell", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "255", ",", "1"}], "}"}]}], "]"}], ",", 
                    
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    RowBox[{"rCell", "//", "Dynamic"}], ",", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", "\"\<Red\>\""}], 
                    "}"}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"gCell", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "255", ",", "1"}], "}"}]}], "]"}], ",", 
                    
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    RowBox[{"gCell", "//", "Dynamic"}], ",", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", "\"\<Green\>\""}],
                     "}"}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"bCell", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "255", ",", "1"}], "}"}]}], "]"}], ",", 
                    
                    RowBox[{"Spacer", "[", "2", "]"}], ",", 
                    RowBox[{"bCell", "//", "Dynamic"}], ",", 
                    RowBox[{"Spacer", "[", "2", "]"}], ",", "\"\<Blue\>\""}], 
                    "}"}], "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
                    "}"}], "]"}]}], ")"}], "}"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "]"}], "]"}], "//", "Dynamic"}], 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Size", " ", "-", " ", "cell"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"textWrapper", "[", "\"\<Size:\>\"", "]"}], ",", 
                    RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\"\<{\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "16"}], "]"}], "&"}]}], ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"xCellSize", "//", "Dynamic"}], ",", 
                    RowBox[{"Prepend", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", "50", "]"}], ",", "Automatic"}], 
                    "]"}], ",", 
                    RowBox[{"MenuStyle", "\[Rule]", "11"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\"\<,\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "16"}], "]"}], "&"}]}], ",", 
                    RowBox[{"PopupMenu", "[", 
                    RowBox[{
                    RowBox[{"yCellSize", "//", "Dynamic"}], ",", 
                    RowBox[{"Prepend", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", "50", "]"}], ",", "Automatic"}], 
                    "]"}], ",", 
                    RowBox[{"MenuStyle", "\[Rule]", "11"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\"\<}\>\"", "//", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "16"}], "]"}], "&"}]}]}], "}"}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
                    RowBox[{"ImageSize", "->", "w"}]}], "]"}]}], "}"}], "]"}],
                     ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{"Alignment", " ", "-", " ", "cell"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"Row", "[", 
                    RowBox[{
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    "textWrapperCentered", "[", 
                    "\"\<Horizontal Alignment\>\"", "]"}], ",", 
                    RowBox[{"SetterBar", "[", 
                    RowBox[{
                    RowBox[{"horAlignCell", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Automatic", "->", "\"\<None\>\""}], ",", "Left", 
                    ",", "Center", ",", "Right"}], "}"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "->", "Center"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Spacer", "[", "5", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    "textWrapperCentered", "[", "\"\<Vertical Alignment\>\"", 
                    "]"}], ",", 
                    RowBox[{"SetterBar", "[", 
                    RowBox[{
                    RowBox[{"verAlignCell", "//", "Dynamic"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Automatic", "->", "\"\<None\>\""}], ",", 
                    "Bottom", ",", "Center", ",", "Top"}], "}"}], ",", 
                    RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"Alignment", "->", "Center"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Center"}]}], "]"}]}], 
                    "\[IndentingNewLine]", "}"}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Center"}], ",", 
                    RowBox[{"Dividers", "\[Rule]", "Center"}], ",", 
                    RowBox[{"FrameStyle", "->", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "0.5", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", ".75", "]"}]}], "}"}]}]}], 
                   "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
                RowBox[{"Alignment", "\[Rule]", "Center"}], ",", 
                RowBox[{"Dividers", "\[Rule]", "Center"}], ",", 
                RowBox[{"FrameStyle", "->", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"AbsoluteThickness", "[", "1.25", "]"}], ",", 
                   "textColor"}], "}"}]}], ",", 
                RowBox[{"Spacings", "\[Rule]", "0"}]}], "]"}]}], 
             "\[IndentingNewLine]", "]"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"WindowTitle", "\[Rule]", "\"\<Table Utility\>\""}], ",", 
          RowBox[{"WindowSize", "\[Rule]", "All"}], ",", 
          RowBox[{"CellMargins", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Saveable", "\[Rule]", "False"}]}], "]"}], "]"}]}], "]"}]}],
     "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.856108885344795*^9, 3.8561089195335913`*^9}, 
   3.856108977634145*^9, {3.856109029012589*^9, 3.8561090514308767`*^9}, {
   3.8561091355371943`*^9, 3.8561091873534317`*^9}, {3.8561092414447317`*^9, 
   3.856109245990539*^9}, {3.8561093098159237`*^9, 3.856109365617145*^9}, {
   3.856109402383048*^9, 3.856109429833552*^9}, {3.856109543520918*^9, 
   3.8561095536603117`*^9}, {3.856109665007069*^9, 3.8561097022082*^9}, {
   3.856109787634508*^9, 3.8561098122949553`*^9}, {3.85611002205904*^9, 
   3.8561100664297447`*^9}, {3.8561103990017757`*^9, 3.85611041614616*^9}, {
   3.856110453138403*^9, 3.856110489257773*^9}, {3.85611053517371*^9, 
   3.8561105868056793`*^9}, {3.856110690911314*^9, 3.856110696003063*^9}, 
   3.8561108501265583`*^9, {3.856111187490452*^9, 3.85611122979062*^9}, {
   3.856111274664468*^9, 3.85611127841945*^9}, {3.8561113136278267`*^9, 
   3.856111317031921*^9}, {3.856111352694254*^9, 3.856111394245894*^9}, {
   3.856111497285508*^9, 3.85611150773914*^9}, {3.856213268725721*^9, 
   3.8562132841863337`*^9}, {3.856217117125683*^9, 3.856217135170609*^9}, {
   3.85626119865005*^9, 3.856261217097335*^9}, {3.8562612471653013`*^9, 
   3.856261324888131*^9}, {3.8562613688688107`*^9, 3.856261371478939*^9}, 
   3.856261458471855*^9, {3.85626149785524*^9, 3.856261513499219*^9}, {
   3.8562615917853327`*^9, 3.856261594423624*^9}, {3.856261656090084*^9, 
   3.856261708412629*^9}, {3.8562617405443907`*^9, 3.856261748536569*^9}, {
   3.8562665630304956`*^9, 3.856266586775148*^9}, 3.856266831469947*^9, {
   3.8562668629185553`*^9, 3.8562669023533497`*^9}, 3.856267063284284*^9, {
   3.856267289230257*^9, 3.856267320440113*^9}, {3.8562675382193193`*^9, 
   3.856267558411045*^9}, 3.856269095757391*^9, {3.856269136295*^9, 
   3.856269179931158*^9}, {3.8562692728416967`*^9, 3.856269342426489*^9}, {
   3.856269439957322*^9, 3.8562694605373783`*^9}, {3.856270269125628*^9, 
   3.856270279371398*^9}, {3.8562703394571*^9, 3.8562703631475267`*^9}, {
   3.8562706232936983`*^9, 3.8562706363005133`*^9}, {3.856270686347625*^9, 
   3.856270693285911*^9}, {3.856270766772841*^9, 3.856270776747636*^9}, {
   3.8562708171831903`*^9, 3.856270952849099*^9}, {3.8562722090830708`*^9, 
   3.856272311188924*^9}, {3.856272349187079*^9, 3.856272352921804*^9}, {
   3.8562725881717653`*^9, 3.8562725964664927`*^9}, {3.856349683389106*^9, 
   3.856349687100512*^9}, {3.8563497226822577`*^9, 3.8563497318195868`*^9}, {
   3.856350539044025*^9, 3.85635056232445*^9}, {3.8563506181443853`*^9, 
   3.856350643925158*^9}, {3.856350681039337*^9, 3.8563506860157537`*^9}, {
   3.856350830331596*^9, 3.8563508334568253`*^9}, {3.856350883077099*^9, 
   3.856350893987865*^9}, 3.856351006107882*^9, {3.856352492545746*^9, 
   3.856352502196307*^9}, 3.856353105047567*^9, 3.8563534157074347`*^9, {
   3.856353535743981*^9, 3.856353541949898*^9}, {3.856353605758904*^9, 
   3.856353713301997*^9}, {3.856354673312006*^9, 3.856354680406226*^9}, {
   3.85635582193578*^9, 3.856355823217989*^9}, 3.856355889382213*^9, {
   3.8563559560085287`*^9, 3.8563560407144413`*^9}, 3.856356115641967*^9, {
   3.856356151551258*^9, 3.856356224279907*^9}, {3.85635626673969*^9, 
   3.85635629205999*^9}, {3.85635636490523*^9, 3.856356381565826*^9}, {
   3.856356415091432*^9, 3.856356447885942*^9}, {3.8563565903429213`*^9, 
   3.856356620379882*^9}, {3.856360985761014*^9, 3.85636100472819*^9}, {
   3.856361054882647*^9, 3.856361066308017*^9}, {3.85636110928413*^9, 
   3.856361213964451*^9}, {3.8563612857167673`*^9, 3.856361306228661*^9}, {
   3.856362167232881*^9, 3.856362233328615*^9}, {3.856362271162052*^9, 
   3.8563623130440474`*^9}, {3.8563631887355013`*^9, 3.8563631923189917`*^9}, 
   3.856370691059106*^9, {3.8563780331753283`*^9, 3.8563780777574043`*^9}, {
   3.856378120328446*^9, 3.856378180054164*^9}, {3.85638997665448*^9, 
   3.8563900258616047`*^9}, {3.8563900730019217`*^9, 3.85639007454987*^9}, {
   3.856390267434845*^9, 3.8563902739224453`*^9}, {3.856390403143092*^9, 
   3.8563904209665194`*^9}, {3.856390460722229*^9, 3.85639051472681*^9}, {
   3.856390556635316*^9, 3.856390557295821*^9}, {3.856390678471843*^9, 
   3.856390681644484*^9}, 3.8563909227691193`*^9, {3.856391194120109*^9, 
   3.8563912294713383`*^9}, {3.856391742608534*^9, 3.8563917760287743`*^9}, {
   3.856392108858224*^9, 3.856392111501801*^9}, {3.856392152462975*^9, 
   3.856392182826105*^9}, {3.856392262769247*^9, 3.856392302752266*^9}, {
   3.8563926136871243`*^9, 3.856392636668907*^9}, {3.856392690871867*^9, 
   3.8563927266043043`*^9}, {3.856392798569334*^9, 3.856392825229508*^9}, {
   3.856396255901092*^9, 3.8563962639229918`*^9}, {3.856396306415298*^9, 
   3.856396313412662*^9}, 3.856396399185584*^9, {3.8563964384598923`*^9, 
   3.856396462409925*^9}, {3.856396539989953*^9, 3.856396562782037*^9}, 
   3.856396642743763*^9, 3.85639670264603*^9, 3.8563967861852922`*^9, {
   3.856396997042636*^9, 3.856397007828326*^9}, {3.856397217801009*^9, 
   3.856397314876052*^9}, {3.856397604171682*^9, 3.8563976075029287`*^9}, {
   3.856397653753145*^9, 3.856397654672439*^9}, 3.8563977209579782`*^9, {
   3.8564319918516417`*^9, 3.856432045860183*^9}, {3.856433134705702*^9, 
   3.856433139930956*^9}, {3.856433180383337*^9, 3.856433202927762*^9}, {
   3.856433235472536*^9, 3.8564332487573137`*^9}, {3.8564336615013037`*^9, 
   3.856433665452276*^9}, 3.856433703294791*^9, {3.8564337353043413`*^9, 
   3.8564337531161833`*^9}, {3.8564339435367603`*^9, 
   3.8564339567784033`*^9}, {3.856434107914509*^9, 3.856434108368643*^9}, {
   3.856434142300785*^9, 3.856434176587942*^9}, {3.8564342272869043`*^9, 
   3.856434280450962*^9}, 3.856434326732471*^9, {3.856434438040854*^9, 
   3.856434447907035*^9}, 3.856434602164712*^9, {3.856434672882504*^9, 
   3.856434675633502*^9}, {3.856435955429792*^9, 3.8564359585644712`*^9}, {
   3.8564360211619997`*^9, 3.856436026736*^9}, {3.8564364473995047`*^9, 
   3.8564364513949213`*^9}, {3.856438161289163*^9, 3.856438169488558*^9}, {
   3.856438211138915*^9, 3.85643822457446*^9}, {3.85643826121838*^9, 
   3.856438266268161*^9}, {3.856438450218809*^9, 3.856438453355198*^9}, {
   3.856438499337188*^9, 3.856438511865996*^9}, {3.856438581871254*^9, 
   3.856438589848796*^9}, {3.856438652276353*^9, 3.856438672661502*^9}, {
   3.856439164440003*^9, 3.856439221227754*^9}, {3.8564415469838943`*^9, 
   3.8564415506193247`*^9}, {3.8564416755408907`*^9, 3.856441708044183*^9}, {
   3.856442009198924*^9, 3.856442160484096*^9}, {3.8564422360985518`*^9, 
   3.856442269163446*^9}, {3.856442575744079*^9, 3.8564426039251842`*^9}, {
   3.856442674428594*^9, 3.856442720656863*^9}, {3.8564431414331503`*^9, 
   3.856443147402009*^9}, 3.856443690901002*^9, {3.856444508997385*^9, 
   3.856444585201887*^9}, {3.85644461555378*^9, 3.856444640607172*^9}, {
   3.856444885011425*^9, 3.856444923168581*^9}, {3.856444956239791*^9, 
   3.856445021751957*^9}, {3.8564450902302923`*^9, 3.8564450909358873`*^9}, {
   3.8564451369839077`*^9, 3.856445138166348*^9}, {3.8564452900264587`*^9, 
   3.856445323222101*^9}, {3.856445353731717*^9, 3.856445525314783*^9}, {
   3.8564460101825733`*^9, 3.8564460106532593`*^9}, {3.8564460633831463`*^9, 
   3.856446231884116*^9}, {3.856446389648291*^9, 3.856446420594486*^9}, 
   3.856446574336054*^9, {3.856446644970628*^9, 3.8564466578084383`*^9}, {
   3.856446703976335*^9, 3.856446705800165*^9}, {3.856446928133566*^9, 
   3.856446981562158*^9}, {3.856447014692403*^9, 3.8564470178176394`*^9}, {
   3.856447183238242*^9, 3.85644723989054*^9}, {3.856447407489999*^9, 
   3.856447439788106*^9}, {3.856447509693241*^9, 3.856447534881836*^9}, {
   3.8564475725150957`*^9, 3.856447589511272*^9}, {3.8564476670932903`*^9, 
   3.8564477011165*^9}, {3.856447737892887*^9, 3.8564477790019913`*^9}, {
   3.8564478117170553`*^9, 3.856447857952025*^9}, {3.8564479036636057`*^9, 
   3.8564479095578938`*^9}, {3.856447971500059*^9, 3.856447972447551*^9}, {
   3.85644801143996*^9, 3.856448013520631*^9}, {3.8564480444931107`*^9, 
   3.856448053177363*^9}, {3.856448538486093*^9, 3.856448565751555*^9}, {
   3.856448610119224*^9, 3.8564486381072893`*^9}, {3.856448732934001*^9, 
   3.856448747108029*^9}, {3.856448790969246*^9, 3.856448808341874*^9}, {
   3.856448895179427*^9, 3.856449001514477*^9}, {3.856449112523909*^9, 
   3.856449115439477*^9}, {3.856449209702856*^9, 3.856449229060933*^9}, {
   3.856449300557599*^9, 3.856449318448288*^9}, {3.8564493608592577`*^9, 
   3.856449428865651*^9}, {3.8564512991066103`*^9, 3.856451356492432*^9}, {
   3.856451437561283*^9, 3.8564514629199247`*^9}, {3.8564514968973103`*^9, 
   3.856451498379326*^9}, {3.856453874593755*^9, 3.8564539143247128`*^9}, {
   3.856453950210988*^9, 3.856453951900105*^9}, {3.8564540060484962`*^9, 
   3.8564540536214437`*^9}, 3.8564540973397837`*^9, {3.8564541801406384`*^9, 
   3.856454181568769*^9}, {3.856454227357945*^9, 3.856454228730736*^9}, {
   3.8564544160569687`*^9, 3.8564544303671503`*^9}, {3.856454466209607*^9, 
   3.856454470631575*^9}, {3.8564546479226522`*^9, 3.8564546721889677`*^9}, {
   3.856454739577396*^9, 3.856454767354659*^9}, {3.8564548378388863`*^9, 
   3.856454853686687*^9}, {3.856455199624069*^9, 3.856455247387813*^9}, {
   3.856455369020979*^9, 3.856455452971735*^9}, {3.8564555563482447`*^9, 
   3.856455559566272*^9}, {3.856455612962357*^9, 3.856455627057385*^9}, 
   3.85645570398361*^9, {3.856455780819195*^9, 3.856455789513763*^9}, {
   3.856456126718346*^9, 3.856456129636449*^9}, {3.856456162402319*^9, 
   3.856456174074033*^9}, {3.8564562225340767`*^9, 3.856456354959468*^9}, {
   3.85645653500705*^9, 3.856456540426094*^9}, {3.856456682854162*^9, 
   3.856456694091607*^9}, {3.8564567360769463`*^9, 3.856456739789456*^9}, {
   3.856456824593218*^9, 3.856456830880787*^9}, {3.856457328911044*^9, 
   3.856457353931987*^9}, {3.856457386389797*^9, 3.8564574720106173`*^9}, {
   3.856457524369479*^9, 3.856457531219976*^9}, {3.856457562416561*^9, 
   3.856457615506152*^9}, {3.856457648864018*^9, 3.8564576517436533`*^9}, {
   3.8564578852056923`*^9, 3.856457885947126*^9}, {3.856457950702742*^9, 
   3.856457954515349*^9}, {3.856457986736887*^9, 3.856458080945767*^9}, {
   3.856458328559023*^9, 3.8564583364227037`*^9}, 3.8564584554705687`*^9, {
   3.856458933092218*^9, 3.8564589469865723`*^9}, {3.856459364107771*^9, 
   3.85645937823849*^9}, {3.8564594266770153`*^9, 3.8564594752100983`*^9}, {
   3.856459623664195*^9, 3.856459655039649*^9}, {3.856459706610445*^9, 
   3.856459708240138*^9}, {3.856459758933014*^9, 3.856459783018346*^9}, {
   3.856459813159966*^9, 3.856459829685349*^9}, {3.856459866293521*^9, 
   3.8564598915114937`*^9}, {3.8564599222603683`*^9, 3.856459922562027*^9}, {
   3.856459995078105*^9, 3.856460087810137*^9}, {3.856460174491042*^9, 
   3.856460174905589*^9}, {3.856460214439231*^9, 3.8564602678887787`*^9}, {
   3.856460308420947*^9, 3.856460320279027*^9}, {3.856460353714532*^9, 
   3.856460433374009*^9}, {3.8564605290428057`*^9, 3.856460536634371*^9}, {
   3.856460572398074*^9, 3.85646057501023*^9}, {3.856460645943264*^9, 
   3.856460654915387*^9}, 3.856460699568609*^9, 3.8564607326293697`*^9, {
   3.856460768688661*^9, 3.856460774074106*^9}, {3.856461026694488*^9, 
   3.8564610564912853`*^9}, {3.856466012425426*^9, 3.8564660218121023`*^9}, {
   3.85646605905624*^9, 3.856466130548088*^9}, {3.856466162805187*^9, 
   3.8564662365586033`*^9}, {3.856466273630145*^9, 3.856466285496467*^9}, {
   3.856466357454649*^9, 3.856466395070095*^9}, {3.856466500125338*^9, 
   3.8564665171688004`*^9}, {3.856466555055073*^9, 3.8564665874566383`*^9}, {
   3.856466619373988*^9, 3.856466633516605*^9}, {3.856466666053289*^9, 
   3.856466718655027*^9}, {3.8564671082915363`*^9, 3.85646713187085*^9}, {
   3.856467295974629*^9, 3.856467339560665*^9}, {3.8564673776483307`*^9, 
   3.85646738321729*^9}, {3.85646744552619*^9, 3.8564674678807287`*^9}, {
   3.856467519460724*^9, 3.856467528921204*^9}, {3.8564701307479477`*^9, 
   3.856470238015133*^9}, {3.856470476884883*^9, 3.856470480549202*^9}, {
   3.856470551167412*^9, 3.85647056899649*^9}, {3.8564706024531918`*^9, 
   3.8564706049720097`*^9}, 3.856470988873749*^9, 3.856471074468691*^9, {
   3.856471123982745*^9, 3.856471174741055*^9}, {3.856471232699444*^9, 
   3.856471346005546*^9}, {3.856471406935136*^9, 3.85647154522821*^9}, {
   3.856471585841538*^9, 3.856471591587871*^9}, {3.856471687181616*^9, 
   3.856471695020752*^9}, {3.856471747217684*^9, 3.856471785766534*^9}, {
   3.856472928283616*^9, 3.8564729310097713`*^9}, {3.856473133226074*^9, 
   3.856473135007629*^9}, {3.856473166482074*^9, 3.8564732021675053`*^9}, {
   3.856473415899468*^9, 3.856473455522369*^9}, {3.8564734959865713`*^9, 
   3.856473550124004*^9}, {3.8564735851338167`*^9, 3.856473604674271*^9}, {
   3.856473671380073*^9, 3.856473681491582*^9}, {3.856473737055131*^9, 
   3.8564737383925323`*^9}, 3.8564739458349648`*^9, {3.856474046344195*^9, 
   3.8564741783773108`*^9}, {3.856474222642954*^9, 3.8564742579819717`*^9}, {
   3.856474326571639*^9, 3.856474340073758*^9}, {3.856474444240581*^9, 
   3.856474476261118*^9}, {3.85647464777989*^9, 3.85647475691679*^9}, {
   3.8564749319962893`*^9, 3.856475010587542*^9}, {3.8564772788190393`*^9, 
   3.856477310274825*^9}, {3.856477629861052*^9, 3.8564777250772038`*^9}, {
   3.856477880956038*^9, 3.8564779080565453`*^9}, {3.856477954754081*^9, 
   3.8564779778254433`*^9}, {3.856478238372089*^9, 3.856478273325177*^9}, {
   3.856478478226719*^9, 3.856478489062336*^9}, {3.856478536138081*^9, 
   3.856478608688758*^9}, {3.856478840288456*^9, 3.8564788509271708`*^9}, 
   3.85647989671656*^9, {3.856480527743029*^9, 3.856480530226129*^9}, {
   3.856514737982608*^9, 3.856514771801485*^9}, {3.856514833089958*^9, 
   3.856514837839014*^9}, {3.85651491909676*^9, 3.856514921504512*^9}, {
   3.856514981581143*^9, 3.8565149940901423`*^9}, {3.8565150250742702`*^9, 
   3.856515122436983*^9}, {3.856515230628561*^9, 3.856515241438281*^9}, {
   3.856515307304913*^9, 3.856515317916286*^9}, 3.8565155003275633`*^9, 
   3.856515558389509*^9, {3.8565156866356173`*^9, 3.856515732859136*^9}, {
   3.856516077368227*^9, 3.856516258975276*^9}, {3.8565162985209846`*^9, 
   3.856516304143314*^9}, {3.8565163831090803`*^9, 3.8565164296714983`*^9}, {
   3.856516549032805*^9, 3.856516559341999*^9}, {3.856516712532218*^9, 
   3.856516714700255*^9}, 3.8565168995673037`*^9, {3.85651844731881*^9, 
   3.856518573488855*^9}, {3.8565186741797867`*^9, 3.856518682719277*^9}, {
   3.85651872571675*^9, 3.856518760491249*^9}, {3.856518849153295*^9, 
   3.856518964550247*^9}, {3.8565191052032223`*^9, 3.8565191151615963`*^9}, {
   3.856519155231832*^9, 3.856519226712489*^9}, {3.856519270397767*^9, 
   3.856519475872176*^9}, {3.856519519557241*^9, 3.856519550975814*^9}, {
   3.8565196392059307`*^9, 3.8565196968265038`*^9}, {3.8565214313694763`*^9, 
   3.8565214994917803`*^9}, {3.8565215440946198`*^9, 3.85652158273424*^9}, {
   3.8565216404509153`*^9, 3.856521677052309*^9}, {3.856521736982753*^9, 
   3.8565217401749496`*^9}, {3.856521809790154*^9, 3.8565218957370663`*^9}, {
   3.856522011206627*^9, 3.856522069047929*^9}, {3.856522155035207*^9, 
   3.856522173246319*^9}, {3.856522228862103*^9, 3.8565222558891077`*^9}, {
   3.856522289347579*^9, 3.856522320089213*^9}, {3.856522357191774*^9, 
   3.856522505657508*^9}, {3.856522626058858*^9, 3.856522665522365*^9}, {
   3.856522737861904*^9, 3.856522834876028*^9}, {3.856522892436797*^9, 
   3.8565228989801073`*^9}, {3.856523001746147*^9, 3.856523046997674*^9}, {
   3.8565232134717007`*^9, 3.856523366923594*^9}, 3.856523445884655*^9, {
   3.856523630755962*^9, 3.856523676926836*^9}, 3.856523732757822*^9, {
   3.8565238906331997`*^9, 3.856523897323122*^9}, {3.856523938464841*^9, 
   3.8565239476763983`*^9}, {3.856523982575921*^9, 3.856523992037184*^9}, {
   3.856524030977573*^9, 3.856524048871422*^9}, {3.856524106209609*^9, 
   3.856524152918038*^9}, {3.856524341162476*^9, 3.8565243462063637`*^9}, {
   3.8565243800433493`*^9, 3.8565243959280767`*^9}, {3.856524622039336*^9, 
   3.856524625287622*^9}, {3.856524725350889*^9, 3.856524772972687*^9}, 
   3.8565255788620567`*^9, {3.856525639206135*^9, 3.856525664452825*^9}, {
   3.856525738360647*^9, 3.8565257406674757`*^9}, {3.856525886693022*^9, 
   3.856525888516727*^9}, {3.856525954230174*^9, 3.8565259548337393`*^9}, {
   3.856526073262738*^9, 3.856526084272478*^9}, 3.856526135469584*^9, {
   3.856526303964786*^9, 3.856526309026485*^9}, {3.856526485207165*^9, 
   3.856526491565998*^9}, {3.8565265287133007`*^9, 3.85652653226115*^9}, {
   3.856526790178111*^9, 3.856526790732937*^9}, {3.856526963406073*^9, 
   3.856526989121614*^9}, {3.856527039411669*^9, 3.8565270514965267`*^9}, {
   3.8565288760289516`*^9, 3.856528906104044*^9}, {3.85652898784612*^9, 
   3.856529003673751*^9}, 3.85652906783368*^9, {3.856529116962892*^9, 
   3.856529181102968*^9}, {3.856529270312317*^9, 3.856529290726202*^9}, {
   3.856529509069714*^9, 3.856529552472743*^9}, {3.856529648682001*^9, 
   3.856529659776194*^9}, {3.856529705367804*^9, 3.856529705540599*^9}, {
   3.856529744177641*^9, 3.856529757380137*^9}, 3.856529801292828*^9, {
   3.8565298647143373`*^9, 3.856529948182116*^9}, {3.856529995814464*^9, 
   3.856530005419845*^9}, {3.856530067982519*^9, 3.856530072072156*^9}, {
   3.856530289527566*^9, 3.856530317436274*^9}, {3.85653036012986*^9, 
   3.856530390046574*^9}, 3.856530493897004*^9, {3.856530533619527*^9, 
   3.8565305488976107`*^9}, {3.856530622109744*^9, 3.856530665669094*^9}, {
   3.856530712632906*^9, 3.856530752381044*^9}, {3.8565307850556917`*^9, 
   3.856530823403418*^9}, {3.856530874064701*^9, 3.8565308806036787`*^9}, {
   3.856530915046938*^9, 3.856530916298382*^9}, {3.8565310172868834`*^9, 
   3.8565310467125893`*^9}, {3.8565311262347183`*^9, 
   3.8565311333080397`*^9}, {3.8565314246243563`*^9, 3.856531462722023*^9}, {
   3.856531495038471*^9, 3.856531495979985*^9}, {3.856531593951351*^9, 
   3.856531635912815*^9}, {3.856531676950511*^9, 3.8565317272831182`*^9}, {
   3.856531850192593*^9, 3.856531863576242*^9}, 3.856531921256332*^9, {
   3.8565319655094147`*^9, 3.856531966365922*^9}, {3.856532310889543*^9, 
   3.8565323429090157`*^9}, 3.8565323755526743`*^9, {3.856532430651936*^9, 
   3.8565324350206547`*^9}, 3.856532562767394*^9, {3.8565325998842382`*^9, 
   3.856532643839569*^9}, {3.856532714571018*^9, 3.8565327445217752`*^9}, {
   3.8565328358553534`*^9, 3.856532856495874*^9}, 3.8565329122238503`*^9, {
   3.85653296762989*^9, 3.8565329990377283`*^9}, 3.8565330474849567`*^9, {
   3.856533192708705*^9, 3.8565331928760357`*^9}, 3.856533265422935*^9, {
   3.856533301512396*^9, 3.856533316910874*^9}, 3.856533368410145*^9, {
   3.8565334126442947`*^9, 3.85653341409241*^9}, {3.856534168265731*^9, 
   3.856534172352764*^9}, {3.856534290224347*^9, 3.856534350227263*^9}, {
   3.856534535761855*^9, 3.8565345952807827`*^9}, {3.856534625328908*^9, 
   3.8565346396419897`*^9}, {3.8565346847324343`*^9, 3.85653471294241*^9}, {
   3.856534750631506*^9, 3.856534789693471*^9}, {3.8565350890891447`*^9, 
   3.8565350899237127`*^9}, {3.856535157991641*^9, 3.856535262764902*^9}, {
   3.856535338009242*^9, 3.856535348936417*^9}, {3.856535387008594*^9, 
   3.856535406291078*^9}, {3.856535469345601*^9, 3.856535478921579*^9}, {
   3.856535514453704*^9, 3.8565355397884502`*^9}, 3.856535588058805*^9, 
   3.856536087245475*^9, 3.856536266611402*^9, {3.856536410807514*^9, 
   3.856536431425994*^9}, 3.8565365237347403`*^9, {3.856536636398491*^9, 
   3.856536638736968*^9}, {3.8565366890234423`*^9, 3.856536830780169*^9}, {
   3.8565368664325533`*^9, 3.856536897467649*^9}, {3.856536933314328*^9, 
   3.856536935628981*^9}, {3.8565369943052473`*^9, 3.85653702605545*^9}, 
   3.8565371466637583`*^9, {3.856537216729629*^9, 3.856537273630465*^9}, {
   3.856537551846904*^9, 3.856537628410863*^9}, {3.85653768776562*^9, 
   3.856537693807303*^9}, {3.856537740223152*^9, 3.856537754069738*^9}, {
   3.856537784913493*^9, 3.856537785855463*^9}, {3.856537818502707*^9, 
   3.8565378190284433`*^9}, 3.8565378657419558`*^9, {3.856537956345065*^9, 
   3.856537959408978*^9}, {3.856538002028244*^9, 3.856538067983983*^9}, {
   3.8565380998787527`*^9, 3.856538112544819*^9}, {3.856538221412616*^9, 
   3.856538233798039*^9}, {3.85653827226364*^9, 3.856538363269086*^9}, {
   3.856539057168605*^9, 3.856539122708682*^9}, {3.856539162613612*^9, 
   3.856539206130805*^9}, {3.856539274201765*^9, 3.856539285402548*^9}, {
   3.8565411359328413`*^9, 3.856541271424861*^9}, {3.856548790237739*^9, 
   3.8565487946990557`*^9}, {3.856548960728356*^9, 3.856548968252885*^9}, 
   3.856549026387941*^9, {3.8565511572666388`*^9, 3.8565511577906637`*^9}, {
   3.856551190470193*^9, 3.856551218576346*^9}, {3.85655133234648*^9, 
   3.856551371034552*^9}, {3.856551409196899*^9, 3.8565514555671167`*^9}, {
   3.856551587187344*^9, 3.856551618796878*^9}, {3.8565516566992893`*^9, 
   3.8565517200164423`*^9}, {3.856551772858848*^9, 3.856551775894052*^9}, {
   3.856551811010188*^9, 3.856551813042407*^9}, 3.856551853861649*^9, {
   3.8565519359879017`*^9, 3.856551976731329*^9}, {3.856552045153541*^9, 
   3.856552058207972*^9}, {3.8565523000041103`*^9, 3.856552306158183*^9}, 
   3.8565527509196167`*^9, 3.856552857522389*^9, {3.856552907414603*^9, 
   3.856552908538825*^9}, {3.856552963432629*^9, 3.856552979623571*^9}, {
   3.856553040353985*^9, 3.8565530453591957`*^9}, 3.856553096740664*^9, {
   3.856553143157659*^9, 3.856553169110956*^9}, {3.856553265983603*^9, 
   3.8565532732703457`*^9}, {3.856553343337236*^9, 3.8565533776106367`*^9}, {
   3.856553483622761*^9, 3.8565534966440353`*^9}, {3.856559086942543*^9, 
   3.856559087648513*^9}, {3.8565591808578453`*^9, 3.856559181853919*^9}, 
   3.856559259294805*^9, {3.8565593321102*^9, 3.856559332982552*^9}, {
   3.856559367966477*^9, 3.856559390547614*^9}, {3.856559471823674*^9, 
   3.8565594784537487`*^9}, {3.856559508484611*^9, 3.856559539837914*^9}, {
   3.856559586302642*^9, 3.856559590609995*^9}, {3.8565596550321083`*^9, 
   3.856559704518127*^9}, {3.856559746528036*^9, 3.856559752895701*^9}, {
   3.8565599102203407`*^9, 3.856559916707138*^9}, {3.8565600266741953`*^9, 
   3.856560037974991*^9}, {3.85656007591497*^9, 3.8565601150598993`*^9}, {
   3.8565601878149033`*^9, 3.856560194549881*^9}, {3.85656023721881*^9, 
   3.856560249717689*^9}, {3.856560303118478*^9, 3.856560320455249*^9}, {
   3.856604535726762*^9, 3.856604540112391*^9}, {3.8566045755675917`*^9, 
   3.856604597985072*^9}, {3.856604672801886*^9, 3.8566047516176167`*^9}, {
   3.856604842544161*^9, 3.856604868980245*^9}, {3.8566049032143517`*^9, 
   3.856604911810534*^9}, {3.8566049555888643`*^9, 3.856604980823823*^9}, {
   3.8566052974468718`*^9, 3.856605341119483*^9}, {3.856605449227344*^9, 
   3.856605502930422*^9}, 3.8566055367833977`*^9, {3.856605568558969*^9, 
   3.856605572841734*^9}, 3.856605612481988*^9, {3.856607189917479*^9, 
   3.8566071975850067`*^9}, {3.8566072447725277`*^9, 
   3.8566072783044453`*^9}, {3.856607385155787*^9, 3.856607410788048*^9}, 
   3.856607468235414*^9, 3.856607556617635*^9, {3.856607658252108*^9, 
   3.8566077028928127`*^9}, {3.856607771814801*^9, 3.856607775808982*^9}, {
   3.856609879313304*^9, 3.856609884393059*^9}, 3.856609935403698*^9, {
   3.856628690257963*^9, 3.856628718867722*^9}, {3.8566287704388113`*^9, 
   3.85662895231292*^9}, {3.8566289982917233`*^9, 3.856629129459733*^9}, {
   3.856629222843367*^9, 3.856629224586255*^9}, {3.856629348559081*^9, 
   3.8566294143878098`*^9}, {3.856712293559861*^9, 3.8567123188939543`*^9}, {
   3.8567123697445*^9, 3.856712381997892*^9}, {3.856712483280922*^9, 
   3.856712499911447*^9}, {3.8567125546078568`*^9, 3.856712555551347*^9}, {
   3.856712595351029*^9, 3.856712625795546*^9}, {3.856712811556282*^9, 
   3.85671294209116*^9}, {3.8567130312261143`*^9, 3.856713127555229*^9}, {
   3.856713161638667*^9, 3.8567132100751543`*^9}, 3.856713300727932*^9, {
   3.856713398399001*^9, 3.8567133987802153`*^9}, {3.856713431183982*^9, 
   3.856713491526844*^9}, {3.85671358510375*^9, 3.8567136383267803`*^9}, 
   3.856714105625558*^9, {3.856714182564225*^9, 3.856714187828162*^9}, 
   3.8567142607425547`*^9, 3.85671442357484*^9, {3.8567148669504337`*^9, 
   3.856714886319736*^9}, 3.856714981767521*^9, 3.8567208009377623`*^9, 
   3.856772144677661*^9, {3.857168536200171*^9, 3.857168542449129*^9}, 
   3.85716943645109*^9, {3.857169471493129*^9, 3.857169482154151*^9}, {
   3.880282691415303*^9, 3.8802827407383537`*^9}, {3.880282818888164*^9, 
   3.880282830126561*^9}, {3.880286833888505*^9, 3.880286846056425*^9}, {
   3.880286919584939*^9, 3.880286968894134*^9}, {3.880287051166813*^9, 
   3.880287053368843*^9}, {3.880287229193193*^9, 3.880287229617188*^9}, {
   3.8802872821431513`*^9, 3.8802872875778923`*^9}, {3.8802873366476603`*^9, 
   3.8802873389531927`*^9}, {3.880287414986377*^9, 3.880287429372686*^9}, 
   3.880289144617383*^9, {3.880289207727138*^9, 3.880289212914279*^9}, 
   3.880290405385015*^9, 3.88029046775254*^9, {3.880292534467195*^9, 
   3.880292555468461*^9}, {3.8802925984213543`*^9, 3.880292606456147*^9}, {
   3.880293274635415*^9, 3.88029328589415*^9}, {3.8802933209556303`*^9, 
   3.880293336114518*^9}, {3.8802933866117563`*^9, 3.8802934099472923`*^9}, {
   3.880293469955509*^9, 3.880293553253461*^9}, {3.8802936342511272`*^9, 
   3.880293635447339*^9}, {3.880293674290563*^9, 3.880293686465033*^9}, {
   3.8802937671887712`*^9, 3.880293778245261*^9}, {3.8802938854648113`*^9, 
   3.880293888018238*^9}, {3.880293944133669*^9, 3.88029402077936*^9}, {
   3.880297050621649*^9, 3.8802970836375933`*^9}, {3.8802976573074017`*^9, 
   3.880297747170658*^9}, {3.8802977851305943`*^9, 3.880297807141836*^9}, {
   3.880297894145054*^9, 3.88029794159958*^9}, {3.880297981891293*^9, 
   3.880298001737372*^9}, {3.88029815431859*^9, 3.880298203219398*^9}, {
   3.880298341306604*^9, 3.88029835011267*^9}, {3.880298523943714*^9, 
   3.880298531068346*^9}, {3.880301079461554*^9, 3.8803010823624163`*^9}, {
   3.880301243460462*^9, 3.88030129509818*^9}, {3.88030136689401*^9, 
   3.880301377373996*^9}, {3.8803310989249372`*^9, 3.880331100930632*^9}, {
   3.880331142553104*^9, 3.880331144252508*^9}, {3.880331271670311*^9, 
   3.880331301153755*^9}, {3.8803314242391987`*^9, 3.880331476066051*^9}, 
   3.880331535309657*^9, {3.8803317429796553`*^9, 3.880331744071151*^9}, {
   3.8803318841758413`*^9, 3.880331946145564*^9}, 3.8803319789851913`*^9, {
   3.880332018650342*^9, 3.880332056486532*^9}, {3.880332119249267*^9, 
   3.8803321467032843`*^9}, {3.880332179035576*^9, 3.880332191069695*^9}, {
   3.880332254161118*^9, 3.880332258351363*^9}, {3.8803783293442163`*^9, 
   3.880378353988467*^9}, {3.880378444885776*^9, 3.8803784775515337`*^9}, {
   3.880378510555854*^9, 3.88037854237066*^9}, {3.880378578900498*^9, 
   3.880378614911096*^9}, {3.8803787085087843`*^9, 3.880378712263727*^9}, {
   3.880378914103218*^9, 3.880378917800727*^9}, {3.880379061125721*^9, 
   3.8803791249802837`*^9}, {3.8803792022189083`*^9, 3.880379234777404*^9}, {
   3.880379280980094*^9, 3.8803792842230597`*^9}, {3.8803793306796083`*^9, 
   3.880379333331768*^9}, {3.880379600747588*^9, 3.880379603435029*^9}, {
   3.880379644664467*^9, 3.880379669922248*^9}, {3.8803834041538477`*^9, 
   3.880383437156488*^9}, 3.880383472815508*^9, 3.880384154914822*^9, {
   3.8803843552874527`*^9, 3.8803843559456587`*^9}, {3.880384717897217*^9, 
   3.88038472367455*^9}, 3.8803877586024*^9, {3.880387804690978*^9, 
   3.880388087858849*^9}, {3.880388126325678*^9, 3.880388207670636*^9}, {
   3.880388258233274*^9, 3.88038827928668*^9}, 3.8803883357164373`*^9, {
   3.880388376622933*^9, 3.880388380287368*^9}, 3.880388433726344*^9, {
   3.880388500470697*^9, 3.880388518208*^9}, {3.880388579686346*^9, 
   3.880388669043666*^9}, {3.8803887173844547`*^9, 3.880388746378626*^9}, {
   3.880388782687706*^9, 3.880388789208314*^9}, {3.8803888693689547`*^9, 
   3.880388885005076*^9}, {3.880388934294422*^9, 3.88038898590511*^9}, {
   3.880389075450334*^9, 3.880389111185213*^9}, {3.880389165848428*^9, 
   3.8803891949719343`*^9}, {3.880389230686007*^9, 3.880389316933648*^9}, {
   3.8803893474295387`*^9, 3.8803893672814293`*^9}, {3.880389509877687*^9, 
   3.88038953675423*^9}, 3.8803899174083548`*^9, {3.880390018600569*^9, 
   3.8803900272609243`*^9}, {3.880399909390996*^9, 3.880399929922106*^9}, 
   3.8803999837653637`*^9, {3.880400070486938*^9, 3.8804000822085648`*^9}, 
   3.8804001624705563`*^9, {3.880400221808223*^9, 3.880400276969942*^9}, {
   3.880403264334861*^9, 3.880403289560133*^9}, {3.880403319864917*^9, 
   3.8804033283369226`*^9}, 3.880453025699959*^9, {3.880455249218318*^9, 
   3.880455260589189*^9}, {3.880455314532946*^9, 3.880455364395612*^9}, {
   3.880455606977888*^9, 3.880455648248405*^9}, {3.880455736646906*^9, 
   3.880455817118442*^9}, {3.880455999811015*^9, 3.88045601594033*^9}, {
   3.8804560518679743`*^9, 3.880456060704693*^9}, {3.880456105713437*^9, 
   3.8804561377960377`*^9}, {3.8804562141895027`*^9, 3.880456275240739*^9}, {
   3.88045677877975*^9, 3.880456803977221*^9}, {3.880456842169826*^9, 
   3.880456893635956*^9}, {3.8804569613623877`*^9, 3.880456969111548*^9}, 
   3.8804570694667063`*^9, {3.880457121722797*^9, 3.880457204233197*^9}, {
   3.88045726281076*^9, 3.880457348566957*^9}, {3.8804574653405533`*^9, 
   3.880457515620386*^9}, {3.880457581019424*^9, 3.880457634248447*^9}, {
   3.8804577635205393`*^9, 3.88045780350413*^9}, {3.880457918172852*^9, 
   3.880457969457528*^9}, {3.880458038832161*^9, 3.880458049023552*^9}, {
   3.88045809175918*^9, 3.880458154775607*^9}, {3.880458265886177*^9, 
   3.880458382342313*^9}, {3.880464786058035*^9, 3.880464880131741*^9}, {
   3.880464942300253*^9, 3.880464977467461*^9}, {3.8804682356834784`*^9, 
   3.880468353408745*^9}, {3.880468462051589*^9, 3.880468472243527*^9}, {
   3.880468516865828*^9, 3.880468568375404*^9}, {3.880468611608345*^9, 
   3.8804686346158133`*^9}, {3.88046891549686*^9, 3.8804689283083363`*^9}, {
   3.8804689584428167`*^9, 3.880468996712265*^9}, {3.880469168759603*^9, 
   3.8804692654319487`*^9}, {3.8804693267217007`*^9, 3.880469481218658*^9}, {
   3.8804696312642393`*^9, 3.880469682632943*^9}, {3.880469725606072*^9, 
   3.8804697292807827`*^9}, {3.880469808439981*^9, 3.880469821231059*^9}, 
   3.880469865591189*^9, {3.880469950118781*^9, 3.880469986059792*^9}, {
   3.880470078254348*^9, 3.880470220837029*^9}, {3.8804702687091637`*^9, 
   3.880470294536025*^9}, {3.880470384935196*^9, 3.8804704102209663`*^9}, {
   3.8804705765773163`*^9, 3.880470611350215*^9}, 3.880470654418573*^9, {
   3.880470731068097*^9, 3.880470774293974*^9}, {3.880470805772633*^9, 
   3.880470816694968*^9}, {3.880470998144823*^9, 3.880471016450892*^9}, {
   3.880471194067634*^9, 3.880471211537959*^9}, {3.880471261288032*^9, 
   3.880471289320704*^9}, {3.8804743476632357`*^9, 3.8804744933590097`*^9}, {
   3.880474633105295*^9, 3.880474638727847*^9}, {3.880474742554974*^9, 
   3.88047475489806*^9}, {3.880474800944376*^9, 3.880474804431715*^9}, {
   3.8804841400893497`*^9, 3.880484151362575*^9}, {3.880484234191084*^9, 
   3.880484372299581*^9}, {3.88048440641532*^9, 3.880484487781766*^9}, {
   3.880484931635727*^9, 3.880484935307563*^9}, 3.8804849742042723`*^9, {
   3.880485046780981*^9, 3.88048511834377*^9}, {3.8804851786547527`*^9, 
   3.8804851826134653`*^9}, {3.880485456806457*^9, 3.880485495268944*^9}, {
   3.8804867054067097`*^9, 3.8804867489988737`*^9}, {3.880487142509914*^9, 
   3.8804871881469107`*^9}, {3.880487238937689*^9, 3.880487254983099*^9}, 
   3.88049002453296*^9, 3.880490107872078*^9, {3.880490694405628*^9, 
   3.880490718323258*^9}, {3.880490757053342*^9, 3.8804907875518427`*^9}, {
   3.880492886965315*^9, 3.880492932370049*^9}, {3.8804981618612947`*^9, 
   3.880498192786306*^9}, {3.880498251081642*^9, 3.880498257888362*^9}, {
   3.880498297300194*^9, 3.880498306674653*^9}, 3.88049844475381*^9, {
   3.880498483014453*^9, 3.8804985167408543`*^9}, {3.880498969727212*^9, 
   3.8804990025746527`*^9}, 3.8804990681317167`*^9, {3.880499395997628*^9, 
   3.8804994524830847`*^9}, {3.8804995263396263`*^9, 
   3.8804995622814903`*^9}, {3.880499632361044*^9, 3.880499634516119*^9}, {
   3.880499994191471*^9, 3.8805000664436407`*^9}, 3.880500105569413*^9, 
   3.880500208169054*^9, {3.880500347368155*^9, 3.880500389303864*^9}, {
   3.8805004272965097`*^9, 3.8805005041542664`*^9}, {3.880500584388629*^9, 
   3.880500598980237*^9}, {3.880500633207904*^9, 3.880500670460771*^9}, 
   3.8805007081038933`*^9, {3.880506633497285*^9, 3.8805066374018173`*^9}, 
   3.880509264123323*^9, {3.8805099714943438`*^9, 3.880510005492627*^9}, {
   3.880510092734907*^9, 3.8805101999691687`*^9}, {3.880510236296076*^9, 
   3.880510279750204*^9}, 3.8805104010609426`*^9, {3.880510500824102*^9, 
   3.880510532292802*^9}, 3.880510588952567*^9, {3.880510716638678*^9, 
   3.880510717143517*^9}, {3.880510931979381*^9, 3.880510933036932*^9}, {
   3.880511085281064*^9, 3.88051110337051*^9}, {3.880511222320339*^9, 
   3.880511263157075*^9}, {3.8805112947476397`*^9, 3.8805113075984364`*^9}, {
   3.8805114181775007`*^9, 3.880511450983822*^9}, {3.880511541213646*^9, 
   3.8805115465456333`*^9}, {3.880512729050045*^9, 3.880512730230888*^9}, 
   3.880513246031554*^9, {3.8805132833039713`*^9, 3.880513292551454*^9}, {
   3.880514232176106*^9, 3.880514233999599*^9}, {3.880514317304872*^9, 
   3.8805143313473473`*^9}, {3.88051490728718*^9, 3.880514927693256*^9}, {
   3.880514958338929*^9, 3.880515025153119*^9}, {3.880515193940023*^9, 
   3.880515220059369*^9}, {3.880515252781394*^9, 3.880515260148329*^9}, {
   3.8805152971961603`*^9, 3.880515357558207*^9}, {3.8805154233257227`*^9, 
   3.8805154425401583`*^9}, 3.880515514753738*^9, {3.880515575676242*^9, 
   3.880515627847651*^9}, {3.880515659566847*^9, 3.880515659809696*^9}, {
   3.8805157539744377`*^9, 3.880515754478689*^9}, {3.880542936109741*^9, 
   3.880542949606473*^9}, 3.880542989810586*^9, 3.880543230577709*^9, {
   3.880543326692004*^9, 3.880543350686266*^9}, {3.8805434093308887`*^9, 
   3.8805434927610817`*^9}, {3.8805435896440783`*^9, 3.880543592713648*^9}, {
   3.8805436624877863`*^9, 3.880543674728549*^9}, {3.88054370930364*^9, 
   3.880543716837216*^9}, {3.8805437720732183`*^9, 3.8805437727117443`*^9}, {
   3.88054384852458*^9, 3.880543884118843*^9}, {3.880543916623085*^9, 
   3.880544029555608*^9}, {3.880544159311116*^9, 3.880544183228065*^9}, 
   3.880544531769219*^9, {3.880544588969492*^9, 3.8805446500245934`*^9}, {
   3.880544703452672*^9, 3.880544826942737*^9}, {3.880544859633668*^9, 
   3.8805449082074823`*^9}, {3.880544944815072*^9, 3.880545116437839*^9}, {
   3.880545154742455*^9, 3.880545156047482*^9}, {3.880545197102332*^9, 
   3.880545204646554*^9}, {3.880545312479357*^9, 3.880545326504931*^9}, {
   3.880546307251108*^9, 3.880546324918996*^9}, {3.880553035732575*^9, 
   3.880553046776713*^9}, {3.8805530873068447`*^9, 3.880553122509227*^9}, {
   3.880553649825314*^9, 3.880553728431472*^9}, {3.880553799882114*^9, 
   3.8805538489451942`*^9}, {3.8805538831905413`*^9, 3.880553886379665*^9}, 
   3.880553927681409*^9, {3.8805539743479967`*^9, 3.880553985302072*^9}, 
   3.8805540304797688`*^9, {3.880554074986328*^9, 3.880554084445342*^9}, {
   3.880554376726206*^9, 3.8805544038355007`*^9}, {3.880554468716219*^9, 
   3.880554482664467*^9}, {3.880554518704657*^9, 3.880554531628355*^9}, {
   3.8805545657135763`*^9, 3.880554571786639*^9}, {3.8805546802367563`*^9, 
   3.8805546913644743`*^9}, {3.880554738368142*^9, 3.8805548573178253`*^9}, {
   3.880554962354315*^9, 3.880555054492092*^9}, {3.8805551312414207`*^9, 
   3.880555131701077*^9}, {3.880555167103067*^9, 3.88055518101056*^9}, {
   3.880555220431718*^9, 3.880555278694121*^9}, 3.880555359001603*^9, {
   3.8805553927623262`*^9, 3.880555426658106*^9}, {3.880555465779203*^9, 
   3.880555502687302*^9}, {3.880555536097499*^9, 3.8805555666413317`*^9}, {
   3.8805555969844503`*^9, 3.880555625601658*^9}, {3.8805557152878036`*^9, 
   3.8805558188185*^9}, {3.880555937501699*^9, 3.880555973610015*^9}, {
   3.880556053973709*^9, 3.8805561772728786`*^9}, {3.880556221236661*^9, 
   3.880556236772737*^9}, {3.880556318368285*^9, 3.880556322133025*^9}, {
   3.880556375626659*^9, 3.880556479891081*^9}, {3.880556578803137*^9, 
   3.880556582005414*^9}, {3.880556654766274*^9, 3.880556726984551*^9}, {
   3.880558793305859*^9, 3.88055879519903*^9}, {3.8805588324492292`*^9, 
   3.8805588540500603`*^9}, {3.880558921694357*^9, 3.8805589290817747`*^9}, 
   3.8805593647193947`*^9, 3.880559619080871*^9, {3.880559716037416*^9, 
   3.8805597225676622`*^9}, 3.880559897815275*^9, {3.880560056846887*^9, 
   3.8805600849429283`*^9}, {3.880560156986142*^9, 3.8805601649917603`*^9}, {
   3.880560223691098*^9, 3.8805602481518993`*^9}, {3.880560298508511*^9, 
   3.880560332920278*^9}, {3.880560396895237*^9, 3.880560411692799*^9}, {
   3.880560541102859*^9, 3.880560543084196*^9}, 3.8805605972280807`*^9, 
   3.880564076734017*^9, {3.880564107522853*^9, 3.880564157118623*^9}, {
   3.8805641886948843`*^9, 3.880564219953657*^9}, {3.880564312630307*^9, 
   3.8805644451934443`*^9}, 3.880564534495057*^9, {3.8805697344373817`*^9, 
   3.880569756069001*^9}, {3.880569787135251*^9, 3.880569793737998*^9}, {
   3.880569843892044*^9, 3.8805698511156282`*^9}, {3.8805700981552753`*^9, 
   3.880570100924694*^9}, {3.880570198558004*^9, 3.8805702064581213`*^9}, {
   3.880570274555256*^9, 3.8805702757167673`*^9}, {3.8805703542064466`*^9, 
   3.880570414853512*^9}, {3.880570463559854*^9, 3.880570479634109*^9}, {
   3.880570577709587*^9, 3.880570590437076*^9}, {3.880570631160557*^9, 
   3.880570645484373*^9}, {3.8805707370786324`*^9, 3.880570737922179*^9}, 
   3.880570999174658*^9, {3.880571033583289*^9, 3.880571111564123*^9}, {
   3.8805711473430443`*^9, 3.880571204185265*^9}, {3.880571332625568*^9, 
   3.8805713642940187`*^9}, 3.8805715012635593`*^9, 3.880571653474428*^9, {
   3.8805734667418957`*^9, 3.88057349296875*^9}, {3.8805735284933243`*^9, 
   3.8805735597228537`*^9}, {3.880577752921123*^9, 3.880577756278842*^9}, {
   3.880577798867042*^9, 3.8805778605833273`*^9}, {3.880577897698326*^9, 
   3.8805782184294643`*^9}, {3.88057850891597*^9, 3.880578509635787*^9}, {
   3.8805786138983507`*^9, 3.88057861415333*^9}, 3.880578648516261*^9, 
   3.880578778294298*^9, {3.8805790723885736`*^9, 3.880579076231413*^9}, {
   3.8805791127059317`*^9, 3.880579122132084*^9}, {3.880579470351103*^9, 
   3.880579604255088*^9}, {3.880579663676798*^9, 3.880579681063401*^9}, {
   3.8805797520349007`*^9, 3.880579761470289*^9}, {3.880579810595985*^9, 
   3.880579830241921*^9}, {3.880579918009877*^9, 3.880579923703719*^9}, {
   3.880580006779861*^9, 3.880580014385799*^9}, {3.8805802343411913`*^9, 
   3.880580248095338*^9}, {3.8805803806674356`*^9, 3.8805803948915243`*^9}, {
   3.880580452361835*^9, 3.880580472336177*^9}, {3.880580599162962*^9, 
   3.880580663158037*^9}, {3.8805807448353033`*^9, 3.880580890926052*^9}, {
   3.880580928232761*^9, 3.880580934039489*^9}, {3.8805810684139967`*^9, 
   3.8805810774571247`*^9}, {3.8805811452334747`*^9, 3.880581285772661*^9}, {
   3.880581325498695*^9, 3.880581341428206*^9}, {3.880581384901476*^9, 
   3.8805814735377417`*^9}, {3.8805815382469378`*^9, 3.880581570050685*^9}, {
   3.880581881157267*^9, 3.8805818835195103`*^9}, 3.8805820496908827`*^9, {
   3.8805821667774963`*^9, 3.880582211382051*^9}, 3.880582291823427*^9, {
   3.880582390788756*^9, 3.880582406469225*^9}, {3.880582763171814*^9, 
   3.880582905335442*^9}, {3.880583050435491*^9, 3.880583098750675*^9}, {
   3.880583287571854*^9, 3.880583342831271*^9}, {3.880583442339059*^9, 
   3.88058348845149*^9}, {3.880583674749566*^9, 3.8805836752554073`*^9}, {
   3.8805837570316963`*^9, 3.880583757936241*^9}, {3.880583909824107*^9, 
   3.88058392949028*^9}, {3.880583963476767*^9, 3.880584001022067*^9}, {
   3.880584033687565*^9, 3.8805840391174583`*^9}, {3.8805841482284307`*^9, 
   3.880584292472356*^9}, {3.880584337712735*^9, 3.880584435944626*^9}, {
   3.88058448066418*^9, 3.880584540392281*^9}, {3.880585476455435*^9, 
   3.880585489419911*^9}, {3.880585649370446*^9, 3.880585662797398*^9}, {
   3.880585771563303*^9, 3.88058578939021*^9}, {3.880585911657888*^9, 
   3.8805859143812*^9}, {3.880586360228009*^9, 3.8805864104192944`*^9}, 
   3.880586534247748*^9, {3.880586633499424*^9, 3.8805866628009567`*^9}, {
   3.8805868135244503`*^9, 3.880586816538892*^9}, {3.880586922638982*^9, 
   3.880586940086618*^9}, 3.880587101653943*^9, 3.880587132888567*^9, {
   3.880588844774658*^9, 3.880588849903986*^9}, {3.880588898404964*^9, 
   3.880588940253146*^9}, {3.880589055984078*^9, 3.8805890629658117`*^9}, {
   3.880589278787489*^9, 3.880589342114852*^9}, {3.880589422758255*^9, 
   3.880589445294536*^9}, {3.880589596976338*^9, 3.8805896033228827`*^9}, {
   3.8805897645890417`*^9, 3.8805897739084682`*^9}, {3.8805898067038813`*^9, 
   3.8805898194160347`*^9}, {3.8805900022914762`*^9, 3.880590047159704*^9}, {
   3.88059010253528*^9, 3.880590103022854*^9}, {3.8805905091777163`*^9, 
   3.8805906584211073`*^9}, 3.8805907180878487`*^9, {3.8805915264481916`*^9, 
   3.880591530745997*^9}, {3.880591562593953*^9, 3.880591584550349*^9}, {
   3.880591631780155*^9, 3.880591662130711*^9}, {3.880591726469632*^9, 
   3.880591787318928*^9}, {3.880591824829939*^9, 3.880591848111271*^9}, 
   3.8805920383230867`*^9, 3.8805921202431307`*^9, {3.8805922269019117`*^9, 
   3.88059222961584*^9}, 3.880592262469186*^9, {3.880592329735094*^9, 
   3.880592346987547*^9}, 3.8805924121313257`*^9, {3.880592459823987*^9, 
   3.8805924687479143`*^9}, {3.8805926029418097`*^9, 
   3.8805926064567432`*^9}, {3.880592653309896*^9, 3.880592695612472*^9}, {
   3.880592836288479*^9, 3.880592861083563*^9}, {3.880592919152631*^9, 
   3.880592943554927*^9}, {3.880592985393564*^9, 3.8805930112381687`*^9}, {
   3.880593098591373*^9, 3.880593119693078*^9}, 3.880593654793269*^9, 
   3.8805937599996357`*^9, {3.88059382087849*^9, 3.880593894083509*^9}, {
   3.8805939395656*^9, 3.880593961526835*^9}, {3.880594001415079*^9, 
   3.880594010365609*^9}, {3.880594049392706*^9, 3.8805941129315166`*^9}, {
   3.880594211943657*^9, 3.880594228008857*^9}, {3.88059427671208*^9, 
   3.8805943726096697`*^9}, 3.880595668255042*^9, {3.880595748272319*^9, 
   3.880595777668106*^9}, {3.8805958443045397`*^9, 3.880595899346649*^9}, {
   3.880596398057035*^9, 3.880596404873733*^9}, 3.88063295562428*^9, {
   3.880633006828844*^9, 3.880633074700603*^9}, {3.880633136216301*^9, 
   3.880633176609949*^9}, {3.880633228520314*^9, 3.880633235649086*^9}, {
   3.880633289192354*^9, 3.88063330642756*^9}, {3.880633348059441*^9, 
   3.880633427350121*^9}, {3.8806338336968412`*^9, 3.880633882317301*^9}, {
   3.880634265245595*^9, 3.880634369569667*^9}, {3.880634540739503*^9, 
   3.880634548002139*^9}, {3.880634745608881*^9, 3.880634778554347*^9}, {
   3.880634861670788*^9, 3.880634866631816*^9}, {3.880634917088648*^9, 
   3.880634933140778*^9}, {3.880637306295746*^9, 3.880637315264979*^9}, {
   3.880637355848843*^9, 3.88063749976198*^9}, {3.880637589616157*^9, 
   3.880637865366981*^9}, {3.88063796498813*^9, 3.880637986931981*^9}, {
   3.880638219481798*^9, 3.8806382223061333`*^9}, {3.880638273861343*^9, 
   3.880638310287627*^9}, {3.8806383450857763`*^9, 3.880638432441918*^9}, 
   3.880638497152355*^9, {3.880638528250802*^9, 3.8806385418057337`*^9}, {
   3.880638597931156*^9, 3.880638613966514*^9}, {3.8806386505012608`*^9, 
   3.8806386574959717`*^9}, {3.8806387004749126`*^9, 3.880638701035132*^9}, {
   3.880639080967338*^9, 3.88063912759942*^9}, {3.880639171758459*^9, 
   3.8806391727832403`*^9}, {3.8806415478030453`*^9, 3.88064158815534*^9}, {
   3.8806441076263123`*^9, 3.8806441086793737`*^9}, {3.880644199933196*^9, 
   3.880644210289768*^9}, {3.880644283375865*^9, 3.880644283935166*^9}, {
   3.8806445673335447`*^9, 3.880644591245461*^9}, {3.8806446946866493`*^9, 
   3.8806446951681023`*^9}, {3.8806521137476387`*^9, 
   3.8806521238080673`*^9}, {3.880652163883952*^9, 3.8806521787503633`*^9}, {
   3.8806522428097754`*^9, 3.880652265319212*^9}, {3.88065232900073*^9, 
   3.880652339085064*^9}, {3.8806524206206913`*^9, 3.880652427827963*^9}, {
   3.8806525129722853`*^9, 3.8806525351990843`*^9}, {3.880652568092959*^9, 
   3.880652582735262*^9}, {3.8806526455084333`*^9, 3.880652698371689*^9}, {
   3.880652863215735*^9, 3.8806528648446083`*^9}, {3.880652898043253*^9, 
   3.880652908257464*^9}, 3.880653023737534*^9, {3.880653115195435*^9, 
   3.880653121244376*^9}, {3.880653203716061*^9, 3.880653308072488*^9}, {
   3.880653359564559*^9, 3.880653363123851*^9}, {3.880653415090304*^9, 
   3.8806534556889772`*^9}, {3.880654408308663*^9, 3.880654416944798*^9}, 
   3.880662940964101*^9, {3.880662975422121*^9, 3.880663048026391*^9}, {
   3.8806631148141947`*^9, 3.880663123538512*^9}, {3.88066315924865*^9, 
   3.880663184831925*^9}, {3.8806632484400167`*^9, 3.880663259222588*^9}, {
   3.88066330337536*^9, 3.880663321014591*^9}, {3.8806641249654083`*^9, 
   3.8806641706253023`*^9}, {3.880664217968837*^9, 3.880664226189123*^9}, {
   3.88066429878714*^9, 3.880664332322892*^9}, {3.880664398945949*^9, 
   3.8806644422907267`*^9}, {3.880664692818804*^9, 3.8806647494200993`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"177a1cfd-7c1c-479f-ae8a-ee92d7b2d31b"]
},
WindowSize->{1703, 1328},
WindowMargins->{{411, Automatic}, {Automatic, 168}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"cb17663f-dddf-4711-837c-282e69d30565"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 141669, 2667, 7691, "Input",ExpressionUUID->"177a1cfd-7c1c-479f-ae8a-ee92d7b2d31b"]
}
]
*)

